#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : check_utils
# @Time         : 2024/9/30 13:18
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.caches import rcache
from meutils.decorators.retry import retrying
from meutils.config_utils.lark_utils import get_next_token

from httpx import TimeoutException

from openai import OpenAI, AsyncOpenAI


def skip_cache_func(*args, **kwargs):
    is_valid = args[0]  # 无效key 缓存
    return is_valid

    # return False  # True不缓存 False缓存


async def check_tokens(tokens, check_token: Callable):
    r = []
    for batch in tqdm(list(tokens) | xgroup(32)):
        bools = await asyncio.gather(*map(check_token, batch))
        r += list(itertools.compress(batch, bools))
    return r


@retrying()
@rcache(ttl=30 * 24 * 3600, skip_cache_func=skip_cache_func)
async def check_token_for_siliconflow(api_key, threshold: float = 0):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_siliconflow)

    headers = {
        "Authorization": f"Bearer {api_key}",
        "Accept": "application/json"
    }
    try:

        client = AsyncOpenAI(base_url=os.getenv("SILICONFLOW_BASE_URL"), api_key=api_key)
        # _ = await client.chat.completions.create(
        #     model="Qwen/Qwen3-8B",
        #     messages=[{'role': 'user', 'content': "hi"}],
        #     max_tokens=1)
        # print(_)
        if models := (await client.models.list()).data:
            if threshold <= 0: return True  # 有效key

            async with httpx.AsyncClient(headers=headers, timeout=60) as client:
                response: httpx.Response = await client.get("https://api.siliconflow.cn/v1/user/info")
                response.raise_for_status()

                logger.debug(response.text)
                logger.debug(response.status_code)

                if response.is_success:
                    logger.debug(api_key)
                    total_balance = response.json()['data']['totalBalance']
                    return float(total_balance) >= threshold
        else:
            return False
    except TimeoutException as e:
        # logger.error(traceback.format_exc().strip())

        logger.error("Timeout")

        return True

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
async def check_token_for_openai(api_key, base_url="https://api.stepfun.cn/v1"):
    try:
        client = AsyncOpenAI(
            base_url=base_url,
            api_key=api_key,
        )
        models = await client.models.list()
        logger.debug(models)
        return True

    except Exception as e:
        logger.error(e)
        return False


@retrying()
async def check_token_for_jina(api_key, threshold=1000):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_jina)

    params = {
        "api_key": api_key,  # "jina_c8da77fed9704d558c8def39837960edplTLkNYrsPTJHBF1HcYg_RkRVh0X"
    }

    try:
        async with httpx.AsyncClient(base_url="https://embeddings-dashboard-api.jina.ai/api/v1", timeout=60) as client:
            response: httpx.Response = await client.get("/api_key/user", params=params)
            response.raise_for_status()

            logger.debug(response.text)
            logger.debug(response.status_code)

            if response.is_success:
                data = response.json()
                total_balance = data['wallet']['total_balance']
                return float(total_balance) >= threshold

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
async def check_token_for_moonshot(api_key, threshold: float = 0):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_jina)

    headers = {
        "Authorization": f"Bearer {api_key}",
        "Accept": "application/json"
    }

    try:
        async with httpx.AsyncClient(base_url="https://api.moonshot.cn/v1", headers=headers, timeout=60) as client:
            response: httpx.Response = await client.get("/users/me/balance")
            response.raise_for_status()

            logger.debug(response.text)
            logger.debug(response.status_code)

            if response.is_success:
                data = response.json()
                logger.debug(data)
                balance = data['data']['available_balance']
                return float(balance) >= threshold

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
async def check_token_for_gemini(api_key):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_gemini)
    try:
        client = AsyncOpenAI(
            api_key=api_key,
            base_url=os.getenv("GOOGLE_BASE_URL"),
        )
        await client.models.list()
        return True
    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
async def check_token_for_ppinfra(api_key, threshold: float = 1):  # 1块钱 10000
    if not isinstance(api_key, str):
        return await check_tokens(api_key, partial(check_token_for_ppinfra, threshold=threshold))
    try:
        client = AsyncOpenAI(base_url="https://api.ppinfra.com/v3/user", api_key=api_key)
        data = await client.get("", cast_to=object)
        logger.debug(data)  # credit_balance
        return data["credit_balance"] >= threshold
    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
# @rcache(ttl=120)
async def check_token_for_sophnet(api_key, threshold: float = 1):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_sophnet)

    try:
        client = AsyncOpenAI(base_url=os.getenv("SOPHNET_BASE_URL"), api_key=api_key)
        data = await client.chat.completions.create(
            model="DeepSeek-v3",
            messages=[{"role": "user", "content": "hi"}],
            stream=True,
            max_tokens=1
        )
        return True
    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


#
@retrying()
@rcache(ttl=3600, skip_cache_func=skip_cache_func)
async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[str] = None):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_volc)

    try:
        base_url = os.getenv("VOLC_BASE_URL") or "https://ark.cn-beijing.volces.com/api/v3"
        client = AsyncOpenAI(base_url=base_url, api_key=api_key)

        if purpose:
            response = client.images.generate(
                model="doubao-seedream-3-0-t2i-250415",
                prompt="鱼眼镜头，一只猫咪的头部，画面呈现出猫咪的五官因为拍摄方式扭曲的效果。",
                size="1024x1024",
                response_format="url"
            )
        else:

            response = await client.chat.completions.create(
                model="deepseek-v3-250324",
                messages=[{"role": "user", "content": "hi"}],
                max_tokens=1
            )
        return True
    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


@retrying()
async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_name: Optional[str] = None):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_ppinfra)
    try:
        client = AsyncOpenAI(base_url="https://bigmodel.cn/api/biz/tokenAccounts/list", api_key=api_key)
        data = await client.get("", cast_to=object)
        logger.debug(bjson(data))

        if resource_package_name:
            # "resourcePackageName": "【新用户专享】200万通用模型资源包",
            # "resourcePackageName": "【新用户专享】400次图像、视频生成、搜索工具次包",
            # "resourcePackageName": "【新用户专享】200万通用模型资源包",
            # "resourcePackageName": "【新用户专享】200万GLM-Z1-Air推理资源包",
            # "resourcePackageName": "【新用户专享】30次Vidu系列视频生成次包",
            for d in data["rows"]:
                if resource_package_name.lower() in d["resourcePackageName"].lower():
                    logger.debug(bjson(d))
                    return d["tokenBalance"] >= threshold
        else:
            logger.debug(bjson(data))
            return True

    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


# curl 'https://bigmodel.cn/api/biz/product/createPreOrder' \
#   -H 'accept: application/json, text/plain, */*' \
#   -H 'accept-language: zh' \
#   -H 'authorization: eyJhbGciOiJIUzUxMiJ9.eyJ1c2VyX3R5cGUiOiJQRVJTT05BTCIsInVzZXJfaWQiOjIyNDAwNDUsInVzZXJfa2V5IjoiNTZmNjkxODUtOTBhMS00NDYyLWFhNWYtYTljNjhmMGY0Njc3IiwiY3VzdG9tZXJfaWQiOiI2MTQ2MTc1MjExNDcxMTYwNSIsInVzZXJuYW1lIjoia2JieHYxMDYifQ.3zLefwa8lzQLyNYz0DVqkgdOgm1_ljPEoihza44Wv1r-pEPS08kQFeZm-v2CY3qhslgHh2I3d1LN_mr-9bhQjw' \
#   -
#   -H 'user-agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/138.0.0.0 Safari/537.36' \
#   --data-raw '{"channelCode":"BALANCE","isMobile":false,"num":1,"payPrice":0,"productId":"product-e6e499"}'

@retrying()
@rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
async def check_token_for_fal(token, threshold: float = 0):
    try:
        # data = await AsyncClient(key=token).upload(b'', '', '')
        from fal_client.client import AsyncClient
        data = await AsyncClient(key=token).run(
            "fal-ai/any-llm",
            arguments={
                "model": "meta-llama/llama-3.2-1b-instruct",
                "prompt": "1+1=",
                "max_tokens": 1,
            },
        )
        logger.debug(data)
        return True
    except Exception as exc:
        logger.error(exc)
        return False


@retrying()
@rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
async def check_token_for_gitee(api_key, threshold: float = 1):
    if not isinstance(api_key, str):
        return await check_tokens(api_key, check_token_for_volc)

    try:
        base_url = "https://ai.gitee.com/v1"
        client = AsyncOpenAI(base_url=base_url, api_key=api_key)
        _ = await client.embeddings.create(
            model="Qwen3-Embedding-0.6B",
            input="hi"
        )
        return True
    except TimeoutException as e:
        raise

    except Exception as e:
        logger.error(f"Error: {e}\n{api_key}")
        return False


async def get_valid_token_for_fal(feishu_url: Optional[str] = None):
    feishu_url = feishu_url or "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=iFRwmM"
    _ = await get_next_token(feishu_url, check_token_for_fal, ttl=600)
    logger.debug(_)
    return _


if __name__ == '__main__':
    from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series

    check_valid_token = partial(check_token_for_siliconflow, threshold=-1)

    # arun(check_valid_token("sk-voxrapfsyirpibnjksblyjznfpxfgkyiyazcrjvmjxdcossh"))

    pass
    # arun(check_valid_token("sk-LlB4W38z9kv5Wy1c3ceeu4PHeIWs6bbWsjr8Om31jYvsucRv", threshold=0.1))

    # FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=KVClcs"

    # b = arun(check_token_for_openai(os.getenv("STEP_API_KEY")))

    # arun(get_next_token_for_polling(check_token=check_token_for_openai, feishu_url=FEISHU_URL))

    # arun(check_token_for_jina(["jina_c8da77fed9704d558c8def39837960edplTLkNYrsPTJHBF1HcYg_RkRVh0X"]*10))

    # arun(check_token_for_siliconflow("sk-jcsgbsqkdctaxunqljmghdahokavyliamkcgbhosfsoyaeln"))
    # "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=79272d"
    # arun(check_token_for_moonshot("sk-iabLMgfFvuahlh5u3oM7kk84pjIciRzqCbNTDt15PVxQM78K"))
    # sk-kk7ALp38EG63yPzJtmind5sEPiHipCcI2NbqW97QlWcvJfiW

    # arun(check_token_for_moonshot("sk-Qnr87vtf2Q6MEfc2mVNkVZ4qaoZg3smH9527I25QgcFe7HrT"))

    # arun(check_token_for_ppinfra("sk_DkIaRrPq7sTiRPevhjV9WFZN3FvLk6WhCXOj1JAwu6c"))

    # from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series
    #
    # arun(get_series("https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=PP1PGr"))

    # arun(check_token_for_sophnet(["gzHpp_zRtGaw1IjpepCiWu_ySyke3Hu5wR5VNNYMLyXwAESqZoZWUZ4T3tiWUxtac6n9Hk-kRRo4_jPQmndo-g"]))

    # arun(check_token_for_ppinfra("sk_F0kgPyCMTzmOH_-VCEJucOK8HIrbnLGYm_IWxBToHZQ"))

    # arun(check_token_for_volc("f1f394db-59e9-4cdd-9d12-b11d50173efc"))
    # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))

    # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))

    # arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh",
    #                            resource_package_name='vidu'))

    # arun(check_token_for_fal("56d8a95e-2fe6-44a6-8f7d-f7f9c83eec24:537f06b6044770071f5d86fc7fcd6d6f"))

    # arun(check_token_for_ppinfra("sk_ib2EjSVnXfB5hSlVuckpejRNXLIU3MaD1wxvXnsvdxQ", threshold=18000))

    # arun(check_token_for_gitee("NWVXUPI38OQVXZGOEL3D23I9YUQWZPV23GVVBW1X"))

    arun(get_valid_token_for_fal())


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : commom
# @Time         : 2024/11/26 15:44
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from uptime_kuma_api import UptimeKumaApi, MonitorType

with UptimeKumaApi('https://status.chatfire.cn/') as api:
    # _ = api.login('chatfire', 'chatfirechatfire!')
    _ = api.login_by_token(token="uk2_IwihsMXDSMDJ2FswTbJoO1BJcz2SL2x08JZHHyxK")
    print(_)
    # print(api.get_monitors())
    #
    # api.delete_monitor(21)
    # result = api.add_monitor(
    #     type=MonitorType.HTTP,
    #     method="POST",
    #     name="gpt-3.5-turbo",
    #     url="https://api.chatfire.cn/v1/chat/completions",
    #     body='{"model": "gpt-3.5-turbo", "messages": [{"role": "user", "content": "你好"}]}',
    #     headers='{"authorization":"Bearer sk-5bqzNIxlLOlutnHcZfkjmCKaMHzRKnF3oscA5sTvJy3541C8"}'
    # )


    # result = api.add_monitor(
    #     name="Chatfire",
    #     type=MonitorType.PING,
    #     method="GET",
    #     hostname="api.chatfire.cn"
    # )
    #
    #
    # print(result)
    # api.save_status_page(
    #     slug="test222",
    #     id="test222",
    #     title="test222",
    #     publicGroupList=[
    #         {
    #             'name': 'Services',
    #             'weight': 1,
    #             'monitorList': [
    #                 {
    #                     "id": int(result.get('monitorID'))
    #                 }
    #             ]
    #         }
    #     ]
    # )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : x
# @Time         : 2024/7/29 09:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

s = """

chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiI5MDJkN2ZkMzg3YmI0YzU3YmMyMGYzNDcwYjYyODk2ZiIsImV4cCI6MTczNzg3NDQxOSwibmJmIjoxNzIyMzIyNDE5LCJpYXQiOjE3MjIzMjI0MTksImp0aSI6IjFlMTM0NmMzNjBiYjQwNTI5YzYzNzliNWI3ZjJkZWMwIiwidWlkIjoiNjYxMThkNGQ3ODY4YTA5ODViMmNmNGMyIiwidHlwZSI6InJlZnJlc2gifQ.skIlW8NsvGRf-HNYn22GiFm2iqK9CzhV4ZmjwMWRP9g;chatglm_token_expires=2024-07-30%2016:53:39;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2caf17223220314411852e3e6f0438d03e36e6d1900882faa07f04bb4f;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiI5MDJkN2ZkMzg3YmI0YzU3YmMyMGYzNDcwYjYyODk2ZiIsImV4cCI6MTcyMjQwODgxOSwibmJmIjoxNzIyMzIyNDE5LCJpYXQiOjE3MjIzMjI0MTksImp0aSI6ImVlZTIyZWU1ZDgxZDRjYWI4MTFlNWQ3ZmE4ZjE2M2IxIiwidWlkIjoiNjYxMThkNGQ3ODY4YTA5ODViMmNmNGMyIiwidHlwZSI6ImFjY2VzcyJ9.Z1uYdhjEVzMCnOHZJi2sXu5qrTPHOG97Tgtg93g_j8E;chatglm_user_id=66118d4d7868a0985b2cf4c2;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2266118d4d7868a0985b2cf4c2%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMThkNGQ3ODY4YTA5ODViMmNmNGMyIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2266118d4d7868a0985b2cf4c2%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyZmM5NmIxYmYzNGM0MGM4OTE5MzBhNWYwN2EyMjQxOCIsImV4cCI6MTczNzg3NDY5NywibmJmIjoxNzIyMzIyNjk3LCJpYXQiOjE3MjIzMjI2OTcsImp0aSI6ImNiNjJiMmMwMzM3NDQ1OTViZTgyNGIyY2M1ZWFkZjk2IiwidWlkIjoiNjVlZDY3OGQ2MTNmMTliYWFiMjBiMTkxIiwidHlwZSI6InJlZnJlc2gifQ.jQmTDY9GzLPwAunE6nLrEX2vX591Se9rJ08inrReV4g;chatglm_token_expires=2024-07-30%2016:58:17;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2caf17223220314411852e3e6f0438d03e36e6d1900882faa07f04bb4f;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyZmM5NmIxYmYzNGM0MGM4OTE5MzBhNWYwN2EyMjQxOCIsImV4cCI6MTcyMjQwOTA5NywibmJmIjoxNzIyMzIyNjk3LCJpYXQiOjE3MjIzMjI2OTcsImp0aSI6ImY5MzJiOWVlN2ZhNzRjNWM5MDQ4ODk4ZTJlNjZhNTZlIiwidWlkIjoiNjVlZDY3OGQ2MTNmMTliYWFiMjBiMTkxIiwidHlwZSI6ImFjY2VzcyJ9.JyvHHuCIgGt1aY_NSp7NLwh-Lvn42qJNKa2wbQCZdQU;chatglm_user_id=65ed678d613f19baab20b191;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2265ed678d613f19baab20b191%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjVlZDY3OGQ2MTNmMTliYWFiMjBiMTkxIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2265ed678d613f19baab20b191%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIzODZkZTEyNmY5YmE0MjViOWJkZDY4ODM5ZDJkZTdjMCIsImV4cCI6MTczNzg3NDc2MCwibmJmIjoxNzIyMzIyNzYwLCJpYXQiOjE3MjIzMjI3NjAsImp0aSI6ImY0YzgzNzkwMmUyNDQwZjE4ZTY0MDM4OGEwYTdkZjI4IiwidWlkIjoiNjYxMTkwZWZhZTBiMDlmZTUwMTY5NWVmIiwidHlwZSI6InJlZnJlc2gifQ.07j5dMEXrMaWjfSCWgl1DNN0_iT-Dks_kvn6Tvdia3c;chatglm_token_expires=2024-07-30%2016:59:21;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2caf17223220314411852e3e6f0438d03e36e6d1900882faa07f04bb4f;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIzODZkZTEyNmY5YmE0MjViOWJkZDY4ODM5ZDJkZTdjMCIsImV4cCI6MTcyMjQwOTE2MCwibmJmIjoxNzIyMzIyNzYwLCJpYXQiOjE3MjIzMjI3NjAsImp0aSI6IjYzNWMwY2Y0YjQxODRkMGU4MDIwMGEzNGVjYTlmNDBjIiwidWlkIjoiNjYxMTkwZWZhZTBiMDlmZTUwMTY5NWVmIiwidHlwZSI6ImFjY2VzcyJ9.HQt1On2pOsnKzU_uO33QEyHrArvdcyVjD3IrQ73w1fg;chatglm_user_id=661190efae0b09fe501695ef;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22661190efae0b09fe501695ef%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTkwZWZhZTBiMDlmZTUwMTY5NWVmIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22661190efae0b09fe501695ef%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJmYTgwN2RkMGI0ZGY0ZDE2OGIxMzQ2OWQ0NTViNDMyMyIsImV4cCI6MTczNzg3NDg0OCwibmJmIjoxNzIyMzIyODQ4LCJpYXQiOjE3MjIzMjI4NDgsImp0aSI6IjVmNzIwZjY5ODcyMTRmNWI4MjVjMmUzMjAzZjIxZGNhIiwidWlkIjoiNjYxMTgxYjBlMmI3ZTk4MDIzMWEzZDU1IiwidHlwZSI6InJlZnJlc2gifQ.vxnT4MkZ7f4cF2IOX-KMEFfIuQbVUEAXF_Lwmfuxq1M;chatglm_token_expires=2024-07-30%2017:00:48;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2caf17223220314411852e3e6f0438d03e36e6d1900882faa07f04bb4f;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJmYTgwN2RkMGI0ZGY0ZDE2OGIxMzQ2OWQ0NTViNDMyMyIsImV4cCI6MTcyMjQwOTI0OCwibmJmIjoxNzIyMzIyODQ4LCJpYXQiOjE3MjIzMjI4NDgsImp0aSI6ImIzYzkwNmY0ZDg0NjQzYmI5ZGYxY2RhNjc1MjM2MGQ0IiwidWlkIjoiNjYxMTgxYjBlMmI3ZTk4MDIzMWEzZDU1IiwidHlwZSI6ImFjY2VzcyJ9.OHRjku8F3k4baRhInUmEI5c_ncxrWgNGlI4qS7Wsk6E;chatglm_user_id=661181b0e2b7e980231a3d55;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22661181b0e2b7e980231a3d55%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTgxYjBlMmI3ZTk4MDIzMWEzZDU1In0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22661181b0e2b7e980231a3d55%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyY2ExYzBjMGE2MDE0YTBiYmI4MjkwNzI5OWU4MDEwZiIsImV4cCI6MTczNzg3NTA1MSwibmJmIjoxNzIyMzIzMDUxLCJpYXQiOjE3MjIzMjMwNTEsImp0aSI6IjNkNzI4YjJlNjdmYzRlYjY4ZjY4ZmE3NzhlMmZmZTFmIiwidWlkIjoiNjYyOTBlN2M3NmUxZGRmNjBhOTkzZWM0IiwidHlwZSI6InJlZnJlc2gifQ.RXxqocEHQ0Qj4JSxFEUtbEhXgQgn5zPAcPlmR4If64M;chatglm_token_expires=2024-07-30%2017:04:11;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2caf17223220314411852e3e6f0438d03e36e6d1900882faa07f04bb4f;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyY2ExYzBjMGE2MDE0YTBiYmI4MjkwNzI5OWU4MDEwZiIsImV4cCI6MTcyMjQwOTQ1MSwibmJmIjoxNzIyMzIzMDUxLCJpYXQiOjE3MjIzMjMwNTEsImp0aSI6ImY2OTJiZDNkMWZhZjQ4NjU4MDg4M2RmZjdiMDlkMWE1IiwidWlkIjoiNjYyOTBlN2M3NmUxZGRmNjBhOTkzZWM0IiwidHlwZSI6ImFjY2VzcyJ9.mRiUNTfdh7dBRIFLgbnetPfuaSnjdH3o73XVAXnlvww;chatglm_user_id=66290e7c76e1ddf60a993ec4;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2266290e7c76e1ddf60a993ec4%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYyOTBlN2M3NmUxZGRmNjBhOTkzZWM0In0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2266290e7c76e1ddf60a993ec4%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D

chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIwZWEyNjNmMmM1NTE0MDJhYTNlODRiYzY2YjAyZWEzMCIsImV4cCI6MTczNzg3NjMyNCwibmJmIjoxNzIyMzI0MzI0LCJpYXQiOjE3MjIzMjQzMjQsImp0aSI6ImJlNDk3YmFjMDdiOTQzMTNiZWQyNDhmNDE3YWExNTM1IiwidWlkIjoiNjYxMTg3MDYyYWJlNzU2YmVkMzE1MTZkIiwidHlwZSI6InJlZnJlc2gifQ.Ux7Jw_OOI10uNq8Ag2Jhasg8QrBUmNRxPLAvzrzMlyE;chatglm_token_expires=2024-07-30%2017:25:24;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIwZWEyNjNmMmM1NTE0MDJhYTNlODRiYzY2YjAyZWEzMCIsImV4cCI6MTcyMjQxMDcyNCwibmJmIjoxNzIyMzI0MzI0LCJpYXQiOjE3MjIzMjQzMjQsImp0aSI6IjBiZTNhYjg0MmVhYTRmNGQ4YThjMGMzM2UyNTdlYWVlIiwidWlkIjoiNjYxMTg3MDYyYWJlNzU2YmVkMzE1MTZkIiwidHlwZSI6ImFjY2VzcyJ9.q2xRDpUOGueLRI8izSuSYDdNdCycMAVfMqGsWbyjKBg;chatglm_user_id=661187062abe756bed31516d;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22661187062abe756bed31516d%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTg3MDYyYWJlNzU2YmVkMzE1MTZkIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22661187062abe756bed31516d%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyZjMzNzNhZWJiOTY0NWU3ODljMGZlYTk0NjYwZGM5NSIsImV4cCI6MTczNzg3NjQ1MSwibmJmIjoxNzIyMzI0NDUxLCJpYXQiOjE3MjIzMjQ0NTEsImp0aSI6ImI5MjllMTU3NWFkZTQyYmFhYWY3YTZmZjc2NmRhYWJlIiwidWlkIjoiNjYyOTE4YWZkZjU3YmEyNjIxMzk5OTAzIiwidHlwZSI6InJlZnJlc2gifQ.a98sfwbsgzNRGT2QOa1tqTFzBzFn33EfPLSGPpoEbNE;chatglm_token_expires=2024-07-30%2017:27:31;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIyZjMzNzNhZWJiOTY0NWU3ODljMGZlYTk0NjYwZGM5NSIsImV4cCI6MTcyMjQxMDg1MSwibmJmIjoxNzIyMzI0NDUxLCJpYXQiOjE3MjIzMjQ0NTEsImp0aSI6IjgzNjNhYTQzMzMwYjQyODZiZWRkZjczZjI3M2JjMjg5IiwidWlkIjoiNjYyOTE4YWZkZjU3YmEyNjIxMzk5OTAzIiwidHlwZSI6ImFjY2VzcyJ9.u9vK7qfCRTphv0wnrLNaN0CyrDRIQ9hMGjA25ZA51mI;chatglm_user_id=662918afdf57ba2621399903;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22662918afdf57ba2621399903%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYyOTE4YWZkZjU3YmEyNjIxMzk5OTAzIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22662918afdf57ba2621399903%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxOTg4MWY5YzJjMzI0MDA5YWQ2ZjZmNjFjOTdjYTZhNSIsImV4cCI6MTczNzg3NjYzNCwibmJmIjoxNzIyMzI0NjM0LCJpYXQiOjE3MjIzMjQ2MzQsImp0aSI6ImQ3YzA1YzQ0MTdmYjQwYzA5MWNmNDc1OTU4ZTJlZDRkIiwidWlkIjoiNjYxMTg4YTRhYmMwZjE5YjdkMjdlZDI4IiwidHlwZSI6InJlZnJlc2gifQ.aaWjrCrD76zZo5idLs6Nt6W4v5sE0npduEsFyvOkIyg;chatglm_token_expires=2024-07-30%2017:30:34;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxOTg4MWY5YzJjMzI0MDA5YWQ2ZjZmNjFjOTdjYTZhNSIsImV4cCI6MTcyMjQxMTAzNCwibmJmIjoxNzIyMzI0NjM0LCJpYXQiOjE3MjIzMjQ2MzQsImp0aSI6IjI1MTA5YjhiODM3ZTQyZjdiNjVhNzdlNWJiZGE4N2UzIiwidWlkIjoiNjYxMTg4YTRhYmMwZjE5YjdkMjdlZDI4IiwidHlwZSI6ImFjY2VzcyJ9.bOm3GYOOTqB21GlbcYxwmAfsV7ZOpYwq0uySl41e00Q;chatglm_user_id=661188a4abc0f19b7d27ed28;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22661188a4abc0f19b7d27ed28%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTg4YTRhYmMwZjE5YjdkMjdlZDI4In0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22661188a4abc0f19b7d27ed28%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIwMjQ4MTk4ZWQ4OTg0NmZhYjI3ZjE0ZTkxMzBjYWNmMiIsImV4cCI6MTczNzg3Njc3NiwibmJmIjoxNzIyMzI0Nzc2LCJpYXQiOjE3MjIzMjQ3NzYsImp0aSI6IjNlYmZjNDZhOTg2NDQyN2Y5N2U0MDcwOGI0M2E2ZjM2IiwidWlkIjoiNjYxMTg1Yjg1NGIwOTE2NjFjMDcwNTcwIiwidHlwZSI6InJlZnJlc2gifQ.yibRRGus5VSxfjbfZy4ZZN4jhiT1Q8cRXI5xZyeWpOI;chatglm_token_expires=2024-07-30%2017:32:56;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIwMjQ4MTk4ZWQ4OTg0NmZhYjI3ZjE0ZTkxMzBjYWNmMiIsImV4cCI6MTcyMjQxMTE3NiwibmJmIjoxNzIyMzI0Nzc2LCJpYXQiOjE3MjIzMjQ3NzYsImp0aSI6IjQzNDVjOTNmNjllMjRiMTU5ZWQ5YmU5MmU4OTNlMjJjIiwidWlkIjoiNjYxMTg1Yjg1NGIwOTE2NjFjMDcwNTcwIiwidHlwZSI6ImFjY2VzcyJ9.3FdJXKppR_smNtwxN3mmYcESMcH9nimM40JpSfXGSbs;chatglm_user_id=661185b854b091661c070570;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%22661185b854b091661c070570%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTg1Yjg1NGIwOTE2NjFjMDcwNTcwIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%22661185b854b091661c070570%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJkNmE4N2E1NjA1NjE0MmQyYTBiN2ViMWIxMDgzMTU1MiIsImV4cCI6MTczNzg3NjgzNSwibmJmIjoxNzIyMzI0ODM1LCJpYXQiOjE3MjIzMjQ4MzUsImp0aSI6Ijg3ZDdkNmE1MTFiYzQ1NTE4MTUyMTkxZDdiMDdkYTkzIiwidWlkIjoiNjYyOTBkZDFhNmQ5YWZlM2U2ZjFjMDg2IiwidHlwZSI6InJlZnJlc2gifQ.MRuqTE0ID5oPZ9887UoxRB34dko6UygHSBXRKmc1O4Y;chatglm_token_expires=2024-07-30%2017:33:56;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJkNmE4N2E1NjA1NjE0MmQyYTBiN2ViMWIxMDgzMTU1MiIsImV4cCI6MTcyMjQxMTIzNSwibmJmIjoxNzIyMzI0ODM1LCJpYXQiOjE3MjIzMjQ4MzUsImp0aSI6Ijc1OTlmMzI2MDAxMjQ2ZWM5Yjc2Y2JmYWUyOGMwZTU5IiwidWlkIjoiNjYyOTBkZDFhNmQ5YWZlM2U2ZjFjMDg2IiwidHlwZSI6ImFjY2VzcyJ9.NSsz-gsaxPes9tCmQPwOwS6keYHZuwut4AMJidpY4SM;chatglm_user_id=66290dd1a6d9afe3e6f1c086;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2266290dd1a6d9afe3e6f1c086%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYyOTBkZDFhNmQ5YWZlM2U2ZjFjMDg2In0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2266290dd1a6d9afe3e6f1c086%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiI3NmRlNWZjMTcwMGU0MTgwOWNiMTc1MDg0ZGVlYzNkZSIsImV4cCI6MTczNzg3NjkwNywibmJmIjoxNzIyMzI0OTA3LCJpYXQiOjE3MjIzMjQ5MDcsImp0aSI6ImFkNGJjMGNhMjQ4MjQ3ODFiN2RkMThjNjUwZDE1NmQ1IiwidWlkIjoiNjZhODk3YWFkMjc3ZDM1NjczZmJkMGJkIiwidHlwZSI6InJlZnJlc2gifQ.BzRKk05ugkbar0gdJWiB5F4-kx3QIpllZPLE0JpzwMQ;chatglm_token_expires=2024-07-30%2017:35:07;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiI3NmRlNWZjMTcwMGU0MTgwOWNiMTc1MDg0ZGVlYzNkZSIsImV4cCI6MTcyMjQxMTMwNywibmJmIjoxNzIyMzI0OTA3LCJpYXQiOjE3MjIzMjQ5MDcsImp0aSI6ImViNzFjZDY5NTU0MTRhNGU5NWRkM2EzMzBmZjAyN2RlIiwidWlkIjoiNjZhODk3YWFkMjc3ZDM1NjczZmJkMGJkIiwidHlwZSI6ImFjY2VzcyJ9.E7bR4n5xSvg-Mg0P3oNbzeL9CumxQev5ybvcf2xJ888;chatglm_user_id=66a897aad277d35673fbd0bd;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2266a897aad277d35673fbd0bd%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjZhODk3YWFkMjc3ZDM1NjczZmJkMGJkIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2266a897aad277d35673fbd0bd%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
chatglm_refresh_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMDdlZDVkMDhlY2M0YzFmOGQ1NGU4OGQyMzVmMDYxZCIsImV4cCI6MTczNzg3NzYwNiwibmJmIjoxNzIyMzI1NjA2LCJpYXQiOjE3MjIzMjU2MDYsImp0aSI6ImQxNGNkZTk1ODg2NTRjZjJhZmMzMTYyYzhkOGU3YWZhIiwidWlkIjoiNjYxMTdjNGI1NGIwOTE2NjFjMDZmZWFlIiwidHlwZSI6InJlZnJlc2gifQ.4puphxxCPi5zXIsb1CxuuoJthILYgs9b31Hacq5BePg;chatglm_token_expires=2024-07-30%2017:46:46;_ga=GA1.1.857418861.1710149493;_ga_PMD05MS2V9=GS1.1.1717136504.55.1.1717136531.0.0.0;acw_tc=784e2cae17223240382974906e0493810a5e816c120521bdaa680eed2ef47e;chatglm_token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMDdlZDVkMDhlY2M0YzFmOGQ1NGU4OGQyMzVmMDYxZCIsImV4cCI6MTcyMjQxMjAwNiwibmJmIjoxNzIyMzI1NjA2LCJpYXQiOjE3MjIzMjU2MDYsImp0aSI6IjkzYWQ4MWM5Yjc3NTRkNjE5NWRlMzViZTZjNDMyZTQyIiwidWlkIjoiNjYxMTdjNGI1NGIwOTE2NjFjMDZmZWFlIiwidHlwZSI6ImFjY2VzcyJ9.mGe70qqPwxOatlavKM_TIcbULIkqG0M0KzqW8sy157E;chatglm_user_id=66117c4b54b091661c06feae;sensorsdata2015jssdkchannel=%7B%22prop%22%3A%7B%22_sa_channel_landing_url%22%3A%22%22%7D%7D;sensorsdata2015jssdkcross=%7B%22distinct_id%22%3A%2266117c4b54b091661c06feae%22%2C%22first_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%2C%22props%22%3A%7B%22%24latest_traffic_source_type%22%3A%22%E7%9B%B4%E6%8E%A5%E6%B5%81%E9%87%8F%22%2C%22%24latest_search_keyword%22%3A%22%E6%9C%AA%E5%8F%96%E5%88%B0%E5%80%BC_%E7%9B%B4%E6%8E%A5%E6%89%93%E5%BC%80%22%2C%22%24latest_referrer%22%3A%22%22%2C%22_latest_wx_ad_click_id%22%3A%22%22%2C%22_latest_wx_ad_hash_key%22%3A%22%22%2C%22_latest_wx_ad_callbacks%22%3A%22%22%7D%2C%22identities%22%3A%22eyIkaWRlbnRpdHlfY29va2llX2lkIjoiMThlMmNkYTYxMWExNmIwLTA5NWU2NGI2ZTMyMjU4LTFmNTI1NjM3LTIwNzM2MDAtMThlMmNkYTYxMWIxZGVmIiwiJGlkZW50aXR5X2xvZ2luX2lkIjoiNjYxMTdjNGI1NGIwOTE2NjFjMDZmZWFlIn0%3D%22%2C%22history_login_id%22%3A%7B%22name%22%3A%22%24identity_login_id%22%2C%22value%22%3A%2266117c4b54b091661c06feae%22%7D%2C%22%24device_id%22%3A%2218e2cda611a16b0-095e64b6e32258-1f525637-2073600-18e2cda611b1def%22%7D
"""

for  i in s.split() | xmap_(lambda s: s.split(';')[0].split('=')[1]):
    print(i)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : yuanbao
# @Time         : 2024/6/11 18:56
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from aiostream import stream

from meutils.pipe import *
from meutils.io.image import image2nowatermark_image

from meutils.llm.utils import oneturn2multiturn
from meutils.schemas.openai_types import CompletionRequest
from meutils.schemas.image_types import HunyuanImageRequest

from meutils.schemas.yuanbao_types import FEISHU_URL, SSEData, YUANBAO_BASE_URL, API_CHAT, API_GENERATE_ID, \
    API_DELETE_CONV, \
    GET_AGENT_CHAT
from meutils.config_utils.lark_utils import get_next_token_for_polling, aget_spreadsheet_values


# import rev_HunYuan


class Completions(object):

    @classmethod
    async def generate(cls, request: HunyuanImageRequest):
        response = cls().create(image_request=request)
        urls = await stream.list(response)
        urls = await asyncio.gather(*map(image2nowatermark_image, urls))

        return {
            "data": [{"url": url} for url in urls]
        }

    async def create(
            self,
            request: Optional[CompletionRequest] = None,
            image_request: Optional[HunyuanImageRequest] = None,
            token: Optional[str] = None
    ):
        token = token or await get_next_token_for_polling(FEISHU_URL, check_token=check_token)

        logger.debug(token)

        prompt = request and oneturn2multiturn(request.messages) or image_request.prompt

        if isinstance(prompt, list):
            prompt = prompt[-1].get("text", "")  # [{'type': 'text', 'text': 'hi'}]

        payload = {
            "model": "gpt_175B_0404",
            "chatModelId": request.model,
            "version": "v2",
            "supportHint": 2,  # 1

            "prompt": prompt,
            # "displayPrompt": "画条可爱的狗狗",
            # "displayPromptType": 1,
            "multimedia": [],
            # "agentId": "gtcnTp5C1G",

            "plugin": "Adaptive",

            "options": {
                "imageIntention": {
                    "needIntentionModel": True,
                    "backendUpdateFlag": 2,
                    "intentionStatus": True,
                    "userIntention": {
                        "resolution": "1280x1280",
                    }
                }
            },

        }
        if "search" in request.model:
            # deep_seek deep_seek_v3 hunyuan_t1 hunyuan_gpt_175B_0404
            payload['chatModelId'] = request.model.replace('-search', '')
            payload['supportFunctions'] = ["supportInternetSearch"]

        if image_request:
            payload["displayImageIntentionLabels"] = [
                {"type": "resolution", "disPlayValue": "超清", "startIndex": 0, "endIndex": 1}
            ]
            payload["options"]["imageIntention"]["userIntention"].update(
                {
                    "style": image_request.style,

                    "scale": image_request.size,

                    # todo: 默认四张 不生效
                    # "N": image_request.n,
                    # "num": image_request.n,
                    # "Count": image_request.n,

                }
            )

        # logger.debug(bjson(payload))
        headers = {
            'cookie': token
        }
        async with httpx.AsyncClient(base_url=YUANBAO_BASE_URL, headers=headers, timeout=300) as client:
            # chatid = (await client.post(API_GENERATE_ID)).text
            chatid = uuid.uuid4()
            # https://yuanbao.tencent.com/api/chat/90802631-22dc-4d5d-9d3f-f27f57d5fec8'
            async with client.stream(method="POST", url=f"{API_CHAT}/{chatid}", json=payload) as response:
                logger.debug(response.status_code)
                response.raise_for_status()

                references = []
                reasoning = "<think>\n"  # </think>
                async for chunk in response.aiter_lines():
                    sse = SSEData(chunk=chunk)
                    if image_request and sse.image:
                        logger.debug(sse.image)
                        yield sse.image

                    if request:
                        if sse.reasoning_content:
                            yield reasoning
                            yield sse.reasoning_content
                            reasoning = ""
                        elif sse.content and reasoning == "":
                            reasoning = "\n</think>"
                            yield reasoning

                        if sse.search_content:
                            # references
                            df = pd.DataFrame(sse.search_content).fillna('')
                            df['icon'] = "![" + df['sourceName'] + "](" + df['icon_url'] + ")"
                            df['web_site_name'] = df['icon'] + df['web_site_name'] + ": "
                            df['title'] = df['web_site_name'] + "[" + df['title'] + "](" + df['url'] + ")"

                            for i, ref in enumerate(df['title'], 1):
                                references.append(f"[^{i}]: {ref}\n")
                        if sse.content:
                            yield sse.content

                            # logger.debug(sse.content)
                if references:
                    yield '\n\n'
                    for ref in references:
                        yield ref

    def generate_id(self, random: bool = True):
        if random:
            return f'{uuid.uuid4()}'
        return httpx.post(API_GENERATE_ID).text

    def delete_conv(self, chatid):
        response = httpx.post(f"{API_DELETE_CONV}/{chatid}")
        return response.status_code == 200


async def check_token(token):
    headers = {
        "cookie": token
    }
    try:
        async with httpx.AsyncClient(base_url=YUANBAO_BASE_URL, headers=headers, timeout=10) as client:
            response = await client.get("/api/info/general")
            response.raise_for_status()
            logger.debug(response.status_code)
            return True
    except Exception as e:
        logger.error(e)
        return False


if __name__ == '__main__':
    # chatid = generate_id()
    # print(chatid)
    # print(delete_conv(chatid))
    # payload = {
    #     # "model": "gpt_175B_0404",
    #     # "prompt": "1+1",
    #     "prompt": "错了",
    #
    #     # "plugin": "Adaptive",
    #     # "displayPrompt": "1+1",
    #     # "displayPromptType": 1,
    #     # "options": {},
    #     # "multimedia": [],
    #     # "agentId": "naQivTmsDa",
    #     # "version": "v2"
    # }
    # chat(payload)

    # async2sync_generator(Completions(api_key).achat('画条狗')) | xprint
    # request = HunyuanImageRequest(prompt='画条狗', size='16:9')
    # deep_seek deep_seek_v3 hunyuan_t1 hunyuan_gpt_175B_0404
    # model = 'deep_seek_v3-search'
    # model = 'deep_seek-search'
    model = 'deep_seek'
    # model = 'hunyuan_t1'
    # model = 'hunyuan_t1-search'
    model = 'deep_seek-search'

    arun(Completions().create(
        CompletionRequest(
            model=model,
            messages=[{'role': 'user', 'content': '南京天气如何'}],
            stream=True
        ),
        # image_request=request,
        # token=token
    ))
    # arun(Completions.generate(request))

    # df = arun(aget_spreadsheet_values(feishu_url=FEISHU__URL, to_dataframe=True))
    #
    # for i in df[0]:
    #     if not arun(check_token(i)):
    #         print(i)
    #



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chatfire_types
# @Time         : 2024/6/27 17:26
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

MODELS = {
    ""
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/6/20 11:31
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.db.redis_db import redis_aclient
from meutils.apis.utils import make_request
from meutils.schemas.hailuo_types import VideoRequest, VideoResponse, Video
from meutils.config_utils.lark_utils import get_series, get_next_token_for_polling, get_next_token
from meutils.llm.check_utils import check_token_for_ppinfra as check_token

from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks

base_url = "https://api.ppinfra.com/v3"
feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=b0e241"


async def get_valid_token():
    _ = await get_next_token(feishu_url, check_token, min_points=18000, ttl=600)
    logger.debug(_)
    return _


# minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-1080p
async def create_task(request: VideoRequest, api_key: Optional[str] = None):
    api_key = api_key or await get_valid_token()  # 轮询

    payload = {

        "prompt": request.prompt,
        "image_url": request.first_frame_image,

        "duration": request.duration,
        "resolution": request.resolution.upper(),
        "enable_prompt_expansion": request.prompt_optimizer
    }
    response = await make_request(
        base_url=base_url,
        api_key=api_key,

        path="/async/minimax-hailuo-02",
        payload=payload,
    )

    # return response  # {'task_id': 'f97d3f93-bb29-47d9-9327-77e70982bd43'}

    video_response = VideoResponse(
        task_id=response['task_id'],
        base_resp={
            "status_code": 0,
            "status_msg": "Processing"
        }
    )

    await redis_aclient.set(video_response.task_id, api_key, ex=7 * 24 * 3600)  # todo 装饰器
    return video_response


async def get_task(task_id: str):
    token = await redis_aclient.get(task_id)  # 绑定对应的 token
    token = token and token.decode()

    logger.debug(f"token: {token}")
    if not token:
        raise HTTPException(status_code=404, detail="TaskID not found")

    response = await make_request(
        base_url=base_url,
        api_key=token,

        path=f"/async/task-result?task_id={task_id}",

        method='GET'
    )
    logger.debug(bjson(response))

    if code := response.get("code"):
        raise HTTPException(status_code=code, detail=response)
    """
{
    "audios": [],
    "extra": {},
    "images": [],
    "task": {
        "eta": 0,
        "progress_percent": 0,
        "reason": "",
        "status": "TASK_STATUS_SUCCEED",
        "task_id": "f97d3f93-bb29-47d9-9327-77e70982bd43",
        "task_type": "MINIMAX_HAILUO_02_6S_768P"
    },
    "videos": [
        {
            "nsfw_detection_result": null,
            "video_type": "mp4",
            "video_url": "https://faas-minimax-video-1312767721.cos.ap-shanghai.myqcloud.com/prod/281961854701760-ceb3b321-0ed3-43a3-9bb8-ca579a8abd4f.mp4?q-sign-algorithm=sha1&q-ak=AKIDHOHvKVnrgHkyxhCTyOdeSjoiRxGPSJ0V&q-sign-time=1750392487%3B1750396087&q-key-time=1750392487%3B1750396087&q-header-list=host&q-url-param-list=&q-signature=202c563db2ab6385a7ebe3e4650ee01ed3376e06",
            "video_url_ttl": "0"
        }
    ]
}
    """
    video_response = VideoResponse(
        task_id=task_id,
        status="Processing",
        base_resp={
            "status_code": 0,
            "status_msg": "Processing"
        }
    )
    if response['task']['status'] == 'TASK_STATUS_SUCCEED':
        video_response.status = "Success"
        video_response.base_resp.status_msg = "Success"
        # video_response.videos = Video()
        video_url = response['videos'][0]['video_url']
        video_response.file_id = video_url
        video_response.videos = [Video(videoURL=video_url, downloadURL=video_url, status=2)]


    elif any(i in response['task']['status'].lower() for i in {"fail", 'error'}):
        video_response.status = "Failed"
        video_response.base_resp.status_code = 1027
        video_response.base_resp.status_msg = "Failed"

    return video_response  # {'task_id': 'f97d3f93-bb29-47d9-9327-77e70982bd43'}


if __name__ == '__main__':
    api_key = os.getenv('PPIO_API_KEY')

    payload = {
        "image_url": "https://static.ppinfra.com/docs/assets/minimax-hailuo-video-02-input-image.jpg",
        "prompt": "戴着太阳镜的毛茸茸的熊猫在日出时的雪山顶上跳舞，左移运镜",
        "duration": 6,
        "resolution": "768P",
        "enable_prompt_expansion": True
    }

    request = VideoRequest(
        prompt="戴着太阳镜的毛茸茸的熊猫在日出时的雪山顶上跳舞，左移运镜",
        first_frame_image="https://static.ppinfra.com/docs/assets/minimax-hailuo-video-02-input-image.jpg",
        duration=6,
        resolution="768P",
    )
    api_key = None
    r = arun(create_task(request, api_key=api_key))

    # arun(get_task("d8b048d0-5c54-42ef-a691-3feab31693fe"))

    # print(request.model_dump_json(exclude_none=True))

    # arun(get_task("959d759e-da77-42f9-95c5-c29cccc6a894"))

    # arun(get_valid_token())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : __init__.py
# @Time         : 2021/1/31 10:20 下午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm
# @Description  : python meutils/clis/__init__.py

from meutils.pipe import *
from meutils.request_utils import request4retry

from itertools import zip_longest


class Item(BaseModel):
    name = 'name'
    url = ""
    get_data: list = []
    post_data: list = []
    keywords: list = []  # 判断词


class Items(BaseConfig):
    item_list: List[Item]


def monitor_task(item: Item):
    method = 'post' if item.post_data else 'get'
    flags = []
    for get_data, post_data in zip_longest(item.get_data, item.post_data):
        r = request4retry(item.url, method, return_json=False, params=get_data, json=post_data, timeout=3) # 8.0
        if r is None:
            flag = False
        else:
            flag = any(key in r.text for key in item.keywords)
        flags.append(flag)

    return (item.name, any(flags))


def main(filename):
    items = Items.parse_yaml(filename)
    return list(map(monitor_task, items.item_list))


if __name__ == '__main__':
    FILE_NAME = 'monitor.yml'
    print(main(FILE_NAME))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : runwayml_types
# @Time         : 2024/7/16 10:47
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

BASE_URL = "https://api.runwayml.com/v1"

EXAMPLES = [
    {
        "taskType": "europa",
        "internal": False,
        "options": {
            "name": "Gen-3 Alpha 文生视频",
            "seconds": 10,
            "text_prompt": "童话里的世界，如同一个缤纷的调色盘，各种色彩交织在一起，组成了一幅美丽的画卷。那里有翠绿如茵的森林、湛蓝如海的天空、缤纷如梦的城堡，还有各种各样让人惊奇的生物。",
            "seed": 2319398808,
            "exploreMode": True,
            "watermark": False,
            "enhance_prompt": True,
            "width": 1280,
            "height": 768,
            "assetGroupName": "Generative Video"
        }
    },
    {
        "taskType": "gen2",
        "internal": False,
        "options": {
            "name": "Gen-2 文生视频",
            "seconds": 4,
            "gen2Options": {
                "mode": "gen2",
                "seed": 2919970896,
                "interpolate": False,
                "upscale": False,
                "watermark": False,
                "width": 1366,
                "height": 768,
                "motion_score": 22,
                "use_motion_score": True,
                "use_motion_vectors": False,
                "text_prompt": "童话里的世界，如同一个缤纷的调色盘，各种色彩交织在一起，组成了一幅美丽的画卷。那里有翠绿如茵的森林、湛蓝如海的天空、缤纷如梦的城堡，还有各种各样让人惊奇的生物。",
                "style": "cinematic"
            },
            "exploreMode": True,
            "assetGroupName": "Generative Video"
        },
        # "asTeamId": 17249553
    },
    {
        "taskType": "gen2",
        "internal": False,
        "options": {
            "name": "Gen-2 图生视频",
            "seconds": 4,
            "gen2Options": {
                "mode": "gen2",
                "seed": 1235659561,
                "interpolate": True,
                "upscale": True,
                "watermark": False,
                "motion_vector": {
                    "x": -0.5,
                    "y": 0,
                    "z": 0,
                    "r": 0,
                    "bg_x_pan": 0,
                    "bg_y_pan": 0
                },
                "use_motion_score": False,
                "use_motion_vectors": True,
                "text_prompt": "童话里的世界，如同一个缤纷的调色盘，各种色彩交织在一起，组成了一幅美丽的画卷。那里有翠绿如茵的森林、湛蓝如海的天空、缤纷如梦的城堡，还有各种各样让人惊奇的生物。",
                "image_prompt": "https://d2jqrm6oza8nb6.cloudfront.net/datasets/7df0aa53-334b-42d7-95c1-a054732c2166.jpg?_jwt=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJrZXlIYXNoIjoiODhmYTFhN2NjNjVkNjQ5ZiIsImJ1Y2tldCI6InJ1bndheS1kYXRhc2V0cyIsInN0YWdlIjoicHJvZCIsImV4cCI6MTcyMTI2MDgwMH0.DLzXSWLnXAiL2Npm3KE9NnG1IpOzjZCksYC77_DWvlY",
                "init_image": "https://d2jqrm6oza8nb6.cloudfront.net/datasets/7df0aa53-334b-42d7-95c1-a054732c2166.jpg?_jwt=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJrZXlIYXNoIjoiODhmYTFhN2NjNjVkNjQ5ZiIsImJ1Y2tldCI6InJ1bndheS1kYXRhc2V0cyIsInN0YWdlIjoicHJvZCIsImV4cCI6MTcyMTI2MDgwMH0.DLzXSWLnXAiL2Npm3KE9NnG1IpOzjZCksYC77_DWvlY"
            },
            "exploreMode": True,
            "assetGroupName": "Generative Video"
        },
        # "asTeamId": 17249553
    }
]

ASPECT_RATIOS = {
    "1:1": "1024x1024",

    "16:9": "1366x768",
    "9:16": "768x1366",

    "4:3": "1280x960",
    "3:4": "960x1280",

    "21:9": "1344x576",

}

STYLES = {
    "Cinematic",
    "Abandoned",
    "Abstract Sculpture",
    "Advertising",
    "Anime"
}


class MotionVector(BaseModel):
    x: float = 0
    y: float = 0
    z: float = 0.5
    r: float = 0
    bg_x_pan: float = 0
    bg_y_pan: float = 0


class Gen2Options(BaseModel):
    mode: str = "gen2"

    image_prompt: Optional[str] = None
    init_image: Optional[str] = None
    text_prompt: Optional[str] = None

    style: Union[str, Literal[(i for i in STYLES)]] = 'none'

    motion_score: Optional[int] = None
    motion_vector: Optional[MotionVector] = None

    interpolate: bool = False  # Smooth out your frames.
    upscale: bool = False
    use_motion_score: bool = False
    use_motion_vectors: bool = True

    watermark: bool = False
    seed: Optional[int] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.use_motion_score = True if self.motion_score else False
        self.use_motion_vectors = True if self.motion_vector else False


class Options(BaseModel):
    name: str = f'Gen-3 Alpha {np.random.randint(10e9)}'
    assetGroupName: str = 'Generative Video'

    text_prompt: Optional[str] = None  # 文生视频

    gen2Options: Optional[Union[Gen2Options]] = None  # 图生视频 todo gen3

    seconds: int = 5

    watermark: bool = False
    exploreMode: bool = True  # 探索模式 不扣积分（看是否有积分）
    enhance_prompt: bool = True
    width: int = 1280
    height: int = 768

    seed: Optional[int] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)


class RunwayRequest(BaseModel):
    taskType: Literal["europa", "gen2", "gen3"] = 'gen3'

    options: Options

    internal: bool = False
    asTeamId: Optional[int] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.taskType = "europa" if self.taskType == 'gen3' else self.taskType

    class Config:
        json_schema_extra = {
            "examples": EXAMPLES
        }


if __name__ == '__main__':
    # print(RunwayRequest(**EXAMPLES[2]).model_dump_json(indent=4))
    # print(RunwayRequest.Config.json_schema_extra)
    print(RunwayRequest.model_config)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : demo
# @Time         : 2024/11/1 16:53
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

d1 = {
    "type": "curated_styles",
    "image_types": [
        "any",
        "digital_illustration",
        "illustration_3d",
        "digital_illustration_seamless",
        "digital_illustration_pixel_art",
        "digital_illustration_3d",
        "digital_illustration_psychedelic",
        "digital_illustration_hand_drawn",
        "digital_illustration_grain",
        "digital_illustration_glow",
        "digital_illustration_80s",
        "digital_illustration_watercolor",
        "digital_illustration_voxel",
        "digital_illustration_infantile_sketch",
        "digital_illustration_2d_art_poster",
        "digital_illustration_kawaii",
        "digital_illustration_halloween_drawings",
        "digital_illustration_2d_art_poster_2",
        "digital_illustration_engraving_color",
        "digital_illustration_flat_air_art",
        "digital_illustration_hand_drawn_outline",
        "digital_illustration_handmade_3d",
        "digital_illustration_stickers_drawings"
    ],
    "transform_model": "recraftv3",
    "offset": 0,
    "limit": 30
}

d2 = {
    "type": "curated_styles",
    "image_types": [
        "realistic_image",
        "realistic_image_mockup",
        "realistic_image_b_and_w",
        "realistic_image_enterprise",
        "realistic_image_hard_flash",
        "realistic_image_hdr",
        "realistic_image_natural_light",
        "realistic_image_studio_portrait",
        "realistic_image_motion_blur"
    ],
    "transform_model": "recraftv3",
    "offset": 0,
    "limit": 30
}

d3 = {
    "type": "curated_styles",
    "image_types": [
        "any",
        "digital_illustration",
        "illustration_3d",
        "digital_illustration_seamless",
        "digital_illustration_pixel_art",
        "digital_illustration_3d",
        "digital_illustration_psychedelic",
        "digital_illustration_hand_drawn",
        "digital_illustration_grain",
        "digital_illustration_glow",
        "digital_illustration_80s",
        "digital_illustration_watercolor",
        "digital_illustration_voxel",
        "digital_illustration_infantile_sketch",
        "digital_illustration_2d_art_poster",
        "digital_illustration_kawaii",
        "digital_illustration_halloween_drawings",
        "digital_illustration_2d_art_poster_2",
        "digital_illustration_engraving_color",
        "digital_illustration_flat_air_art",
        "digital_illustration_hand_drawn_outline",
        "digital_illustration_handmade_3d",
        "digital_illustration_stickers_drawings"
    ],
    "transform_model": "recraftv3",
    "offset": 0,
    "limit": 30
}

d4 = {
    "type": "curated_styles",
    "image_types": [
        "vector_illustration",
        "vector_illustration_seamless",
        "vector_illustration_line_art",
        "vector_illustration_doodle_line_art",
        "vector_illustration_flat_2",
        "vector_illustration_70s",
        "vector_illustration_cartoon",
        "vector_illustration_kawaii",
        "vector_illustration_linocut",
        "vector_illustration_engraving",
        "vector_illustration_halloween_stickers",
        "vector_illustration_line_circuit"
    ],
    "transform_model": "recraftv3",
    "offset": 0,
    "limit": 30
}


# d1['image_types'] + d2['image_types']+ d3['image_types']+ d4['image_types']

def min_max_normalize(data, feature_range=(0, 1)):
    """
    最大最小归一化函数,保持数据比例不变

    参数:
    data: 输入数据,可以是列表或numpy数组
    feature_range: 目标范围元组,默认为(0,1)

    返回:
    归一化后的数据
    """
    import numpy as np

    data = np.asarray(data)
    min_val = np.min(data)
    max_val = np.max(data)

    # 防止除零
    if max_val == min_val:
        return np.zeros_like(data)

    min_range, max_range = feature_range
    range_scale = max_range - min_range
    data_scale = max_val - min_val

    # 保持比例的归一化
    scale_factor = range_scale / data_scale
    scaled_data = data * scale_factor + (min_range - min_val * scale_factor)

    return scaled_data

min_max_normalize([1000, 3000], feature_range=(1024, 1024))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : x
# @Time         : 2024/11/28 15:42
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from meutils.async_task import worker
from meutils.async_task.tasks import test, kling, hailuo
from celery.result import AsyncResult

# print(worker.conf)

# @shared_task(
#     autoretry_for=(Exception,),      # 自动重试的异常类型
#     retry_kwargs={
#         'max_retries': 3,            # 最大重试次数
#         'countdown': 60              # 重试等待时间（秒）
#     },
#     retry_backoff=True,              # 启用指数退避
#     retry_backoff_max=600,           # 最大退避时间（秒）
#     retry_jitter=True                # 添加随机抖动
# )
# def my_task():
#     try:
#         # 任务逻辑
#         result = some_operation()
#         return result
#     except Exception as exc:
#         logger.error(f"Task failed: {exc}")
#         raise  # 触发自动重试


if __name__ == '__main__':
    # r = test.do_sync_task.apply_async(kwargs={'a': 1, 'b': 2})
    # logger.debug(r.backend)
    # test.ado_sync_task.apply_async(kwargs={'a': 1, 'b': 2})
    # test.ado_sync_task.apply_async(kwargs={'a': 1, 'b': 3})
    # print(AsyncResult("42e191a0-6099-419e-b61d-07bf7e2df2fc").result)
    # result.backend
    # AsyncResult("42e191a0-6099-419e-b61d-07bf7e2df2fc").get()
    # AsyncResult(r.id).result

    # test.do_pydantic_task.apply_async(kwargs={'request': test.Request()})

    # test.do_pydantic_task.apply_async(kwargs={"request": {"method": "POST", "url": "测试"}})

    # print(type(test.do_pydantic_task))

    # test.do_pydantic_task.apply_async(kwargs={"request": {"method": "POST", "url": "测试"}})
    # test.do_pydantic_task.apply_async(kwargs={"request": {"method": "xx"}})
    # test.do_pydantic_task.apply_async(args=({"method": "xxxxxxx"},))

    #
    # test.do_task_retrying.apply_async(kwargs={'name': "###do_task_retrying"})
    # test.do_task_retry.apply_async(kwargs={'name': "###do_task_retry"})
    # test.do_task_retry_backoff.apply_async(kwargs={'name': "###do_task_retry_backoff"})
    # test.ado_pydantic_task.apply_async(kwargs={'name': "###do_task_retry_backoff"})

    test.Request()
    # test.ado_pydantic_task.apply_async(kwargs={"request": None})

    # test.ado_pydantic_task.apply_async(kwargs={"request": test.Request().model_dump()})
    # test.ado_pydantic_task_2.apply_async(kwargs={"request": test.Request().model_dump()})

    # kling.create_task.apply_async(kwargs={"request": kling.kolors_virtual_try_on.TryOnRequest().model_dump()})

    hailuo.create_task.apply_async(kwargs={"request": hailuo.VideoRequest(prompt='a dog').model_dump()})



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : elevenlabs
# @Time         : 2025/7/14 16:36
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.apis.utils import make_request_httpx

UPSTREAM_BASE_URL = "https://api.elevenlabs.io/v1"
UPSTREAM_API_KEY = "sk_9e7ce9190f85579b527beb6e673eb350db9c0cbfe2c7334b"
headers = {
    "xi-api-key": UPSTREAM_API_KEY
}

path = "/text-to-speech/JBFqnCBsd6RMkjVDRZzb"

params = {
    "output_format": "mp3_44100_128"
}
payload = {
    "text": "The first move is what sets everything in motion.",
    "model_id": "eleven_multilingual_v2"
}

path = "speech-to-text"

data = {
    'model_id': "scribe_v1",
}
files = {
    'file': ('xx.mp3', open("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_audio/x1.wav", 'rb'))

}

arun(make_request_httpx(
    base_url=UPSTREAM_BASE_URL,
    path=path,
    # payload=payload,
    data=data,
    files=files,
    headers=headers,
    params=params,
    # debug=True,
))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : models
# @Time         : 2025/7/14 16:47
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *


def create_fal_models(model: str, request: dict):
    if model == "pika":
        duration = request.get("duration")
        resolution = request.get("resolution")

        billing_model = f"{duration}s_{resolution}"
    else:
        duration = request.get("duration", "5")
        resolution = request.get("resolution", "720p")

        billing_model = f"_{duration}s_{resolution}"
    return billing_model



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2025/4/2 13:03
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://ai.google.dev/gemini-api/docs/openai?hl=zh-cn
# genai => openai
# https://googleapis.github.io/python-genai/genai.html#module-genai.models


from meutils.pipe import *
from meutils.decorators.retry import retrying

from meutils.io.files_utils import to_url, to_bytes, guess_mime_type
from meutils.str_utils.regular_expression import parse_url

from meutils.schemas.image_types import ImageRequest, ImagesResponse
from meutils.schemas.openai_types import chat_completion, chat_completion_chunk, CompletionRequest, CompletionUsage

from meutils.config_utils.lark_utils import get_next_token_for_polling
from google import genai
from google.genai import types
from google.genai.types import Part, HttpOptions, HarmCategory, HarmBlockThreshold
from google.genai.types import UploadFileConfig, ThinkingConfig, GenerateContentConfig

from google.genai.types import UserContent, ModelContent, Content
from google.genai.types import Tool, GoogleSearch

FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=bK9ZTt"  # 200

"""
Gemini 1.5 Pro 和 1.5 Flash 最多支持 3,600 个文档页面。文档页面必须采用以下文本数据 MIME 类型之一：

PDF - application/pdf
JavaScript - application/x-javascript、text/javascript
Python - application/x-python、text/x-python
TXT - text/plain
HTML - text/html
CSS - text/css
Markdown - text/md
CSV - text/csv
XML - text/xml
RTF - text/rtf

- 小文件
- 大文件: 需要等待处理
"""
tools = [
    Tool(
        google_search=GoogleSearch()
    )
]


# UploadFileConfig(
#     http_options=HttpOptions(
#         timeout=120,
#     )
# )

class Completions(object):
    def __init__(self, api_key: Optional[str] = None, base_url: Optional[str] = None):
        self.api_key = api_key
        self.base_url = base_url or "https://g.chatfire.cn"
        self.client = None  ####

    async def create_for_search(self, request: CompletionRequest):
        self.client = self.client or await self.get_client()

        if request.model.endswith("-search"):
            request.model = request.model.replace("-search", "")

        chat = self.client.aio.chats.create(
            model=request.model,
            config=GenerateContentConfig(
                tools=tools,
                system_instruction=request.system_instruction or "请根据用户的语言偏好自动调整回复语言",
                # thinking_config=ThinkingConfig(include_thoughts=True, thinking_budget=24576)
            ),
        )
        # print(response.candidates[0].grounding_metadata.search_entry_point.rendered_content)
        # print(response.candidates[0].grounding_metadata.grounding_chunks)

        chunks = await chat.send_message_stream(request.last_user_content)
        async for chunk in chunks:
            if chunk.candidates and chunk.candidates[0].content:
                parts = chunk.candidates[0].content.parts or []
                for part in parts:
                    # logger.debug(part)
                    if part.text:
                        yield part.text

            if chunk.candidates and chunk.candidates[0].grounding_metadata:
                grounding_chunks = chunk.candidates[0].grounding_metadata.grounding_chunks or []
                for grounding_chunk in grounding_chunks:
                    if grounding_chunk.web:
                        yield f"\n\n[{grounding_chunk.web.title}]({grounding_chunk.web.uri})"

    async def create_for_files(self, request: CompletionRequest):
        """todo: 大文件解析"""
        self.client = self.client or await self.get_client()

        contents = []
        if urls := sum(request.last_urls.values(), []):
            logger.debug(urls)
            # https://ai.google.dev/gemini-api/docs/document-processing?hl=zh-cn&lang=python
            file_objects = await self.upload(urls)
            for file_object in file_objects:
                self.check_file(file_object)

            contents += file_objects
            contents.append(request.last_user_content)

        elif request.last_user_content.startswith("http"):
            url, user_content = request.last_user_content.split(maxsplit=1)

            yield "> `⏳️Uploading`\n"
            file_object = await self.upload(url)
            yield f"```json\n{file_object.model_dump_json(indent=4)}\n```\n\n"

            s = time.time()

            yield "[Thinking]("
            for i in range(100):
                file_object = self.client.files.get(
                    name=file_object.name,
                    config={"http_options": {"timeout": 300 * 1000}}
                )

                logger.debug(file_object)

                if file_object.state.name in {"ACTIVE", }:
                    yield f"100%) ✅️✅️✅️{time.time() - s:.2f}s.\n\n"
                    break
                else:
                    yield f"{min(i * 5, 99)}%"

                await asyncio.sleep(3)

            # {'error': {'code': 400,
            #            'message': 'The File cwjpskscrjd79hjezu7dhb is not in an ACTIVE state and usage is not allowed.',
            #            'status': 'FAILED_PRECONDITION'}}
            #
            # while file_object.state.name == "ACTIVE":
            #     logger.debug(file_object)
            #     await asyncio.sleep(1)

            contents += [file_object, user_content]
        else:
            contents.append(request.last_user_content)

        logger.debug(contents)

        if any(i in request.model for i in {"gemini-2.5-pro", "gemini-2.5-flash"}):  # 默认开启思考
            request.reasoning_effort = "low"

        chat = self.client.aio.chats.create(
            model=request.model,
            config=GenerateContentConfig(
                response_modalities=['Text'],
                system_instruction=request.system_instruction or "请根据用户的语言偏好自动调整回复语言",
                thinking_config=ThinkingConfig(thinking_budget=request.reasoning_effort and 1024 or 0),
                # thinking_config=ThinkingConfig(thinking_budget=1024),
            )
        )
        for i in range(5):
            try:
                chunks = await chat.send_message_stream(contents)
                async for chunk in chunks:
                    if chunk.candidates and chunk.candidates[0].content:
                        parts = chunk.candidates[0].content.parts or []
                        for part in parts:
                            # logger.debug(part)
                            if part.text:
                                yield part.text

                break

            except Exception as e:
                logger.debug(f"重试{i}: {e}")
                if "The model is overloaded." in str(e):
                    await asyncio.sleep(1)
                    continue
                else:

                    yield e
                    raise e

    @retrying(title=__name__)
    async def generate(self, request: ImageRequest):  # OpenaiD3
        request.model = "gemini-2.0-flash-exp-image-generation"
        image, prompt = request.image_and_prompt
        parts = [Part.from_text(text=prompt)]
        if image:
            data = await to_bytes(image)
            parts.append(Part.from_bytes(data=data, mime_type="image/png"))

        self.client = self.client or await self.get_client()
        chat = self.client.aio.chats.create(
            model=request.model,
            config=GenerateContentConfig(
                response_modalities=['Text', 'Image'],
            )
        )
        image_response = ImagesResponse()

        response = await chat.send_message(parts)
        if response.candidates and response.candidates[0].content:
            parts = response.candidates[0].content.parts or []
            for part in parts:
                if part.inline_data:
                    image_url = await to_url(part.inline_data.data, mime_type=part.inline_data.mime_type)
                    image_response.data.append({"url": image_url, "revised_prompt": part.text})

        return image_response

    async def create_for_images(self, request: CompletionRequest):
        request.model = "gemini-2.0-flash-exp-image-generation"  ####### 目前是强行

        messages = await self.to_image_messages(request)

        if len(messages) > 1:
            history = messages[:-1]
            message = messages[-1].parts
        else:
            history = []
            message = messages[-1].parts

        self.client = self.client or await self.get_client()
        chat = self.client.aio.chats.create(  # todo: system_instruction
            model=request.model,
            config=GenerateContentConfig(
                response_modalities=['Text', 'Image'],
                # system_instruction=request.system_instruction
            ),
            history=history
        )

        # logger.debug(message)

        # message = [
        #     Part.from_text(text="画条狗")
        # ]

        for i in range(5):
            try:
                chunks = await chat.send_message_stream(message)
                async for chunk in chunks:

                    if chunk.candidates and chunk.candidates[0].content:
                        parts = chunk.candidates[0].content.parts or []
                        for part in parts:
                            # logger.debug(part)
                            if part.text:
                                yield part.text

                            if part.inline_data:
                                image_url = await to_url(
                                    part.inline_data.data,
                                    mime_type=part.inline_data.mime_type
                                )
                                yield f"![image_url]({image_url})"
                break

            except Exception as e:
                logger.debug(f"重试{i}: {e}")
                if "The model is overloaded." in str(e):
                    await asyncio.sleep(1)
                    continue
                else:
                    yield e
                    raise e

    async def to_image_messages(self, request: CompletionRequest):
        # 两轮即可连续编辑图片

        messages = []
        for m in request.messages or []:
            contents = m.get("content")
            if m.get("role") == "assistant":
                assistant_content = str(contents)
                if urls := parse_url(assistant_content):  # assistant
                    datas = await asyncio.gather(*map(to_bytes, urls))

                    parts = [
                        Part.from_bytes(
                            data=data,
                            mime_type="image/png"
                        )
                        for data in datas
                    ]
                    parts += [
                        Part.from_text(
                            text=request.last_assistant_content
                        ),
                    ]
                    messages.append(ModelContent(parts=parts))

            elif m.get("role") == "user":
                if isinstance(contents, list):
                    parts = []
                    for content in contents:
                        if content.get("type") == "image_url":
                            image_url = content.get("image_url", {}).get("url")
                            data = await to_bytes(image_url)

                            parts += [
                                Part.from_bytes(data=data, mime_type="image/png")
                            ]

                        elif content.get("type") == "text":
                            text = content.get("text")
                            if text.startswith('http'):
                                image_url, text = text.split(maxsplit=1)
                                data = await to_bytes(image_url)

                                parts += [
                                    Part.from_bytes(data=data, mime_type="image/png"),
                                    Part.from_text(text=text)
                                ]
                            else:
                                parts += [
                                    Part.from_text(text=text)
                                ]

                    messages.append(UserContent(parts=parts))

                else:  # str
                    if str(contents).startswith('http'):  # 修正提问格式， 兼容 url
                        image_url, text = str(contents).split(maxsplit=1)
                        data = await to_bytes(image_url)
                        parts = [
                            Part.from_bytes(data=data, mime_type="image/png"),
                            Part.from_text(text=text)
                        ]
                    else:
                        parts = [
                            Part.from_text(text=str(contents)),
                        ]
                    messages.append(UserContent(parts=parts))

        return messages

    @retrying(title=__name__)
    async def upload(self, files: Union[str, List[str]]):  # => openai files
        self.client = self.client or await self.get_client()

        if isinstance(files, list):
            return await asyncio.gather(*map(self.upload, files))

        file_config = {
            "name": f"{shortuuid.random().lower()}",
            "mime_type": guess_mime_type(files),
            "http_options": {"timeout": 300 * 1000}
        }

        return await self.client.aio.files.upload(file=io.BytesIO(await to_bytes(files)), config=file_config)

    async def get_client(self):
        api_key = self.api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL, from_redis=True)

        logger.info(f"GeminiClient: {api_key}")

        return genai.Client(
            api_key=api_key,
            http_options=HttpOptions(
                base_url=self.base_url,
                timeout=300 * 1000,
            )
        )

    def check_file(self, file_object):

        for i in range(100):
            file_object = self.client.files.get(
                name=file_object.name,
                config={"http_options": {"timeout": 300 * 1000}}
            )

            logger.debug(file_object)
            if file_object.state.name in {"ACTIVE", }:  # FAILED_PRECONDITION
                break

            time.sleep(3)


if __name__ == '__main__':
    file = "https://oss.ffire.cc/files/kling_watermark.png"

    api_key = os.getenv("GOOGLE_API_KEY")

    # arun(GeminiClient(api_key=api_key).upload(file))
    # arun(GeminiClient(api_key=api_key).upload([file] * 2))
    # arun(GeminiClient(api_key=api_key).create())
    url = "https://oss.ffire.cc/files/nsfw.jpg"
    content = [

        # {"type": "text", "text": "https://oss.ffire.cc/files/nsfw.jpg 移除右下角的水印"},
        # {"type": "text", "text": "https://oss.ffire.cc/files/kling_watermark.png 总结下"},
        # {"type": "text", "text": "https://oss.ffire.cc/files/nsfw.jpg 总结下"},
        {"type": "text", "text": "https://lmdbk.com/5.mp4 总结下"},
        # {"type": "text", "text": "https://v3.fal.media/files/penguin/Rx-8V0MVgkVZM6PJ0RiPD_douyin.mp4 总结下"},

        # {"type": "text", "text": "总结下"},
        # {"type": "image_url", "image_url": {"url": url}},

        # {"type": "text", "text": "总结下"},
        # {"type": "video_url", "video_url": {"url": "https://lmdbk.com/5.mp4"}},
        # {"type": "video_url", "video_url": {"url": "https://lmdbk.com/5.mp4"}},

        # {"type": "video_url", "video_url": {"url": "https://v3.fal.media/files/penguin/Rx-8V0MVgkVZM6PJ0RiPD_douyin.mp4"}}

    ]

    # content = "亚洲多国回应“特朗普关税暂停”"

    # content = "https://oss.ffire.cc/files/nsfw.jpg 移除右下角的水印"

    #
    request = CompletionRequest(
        # model="qwen-turbo-2024-11-01",
        # model="gemini-all",
        # model="gemini-2.0-flash-exp-image-generation",
        model="gemini-2.0-flash",
        # model="gemini-2.5-flash-preview-04-17",
        # model="gemini-2.5-flash-preview-04-17",

        messages=[
            {
                'role': 'user',
                'content': content
            },

        ],
        stream=True,
    )

    # arun(Completions(api_key=api_key).create_for_search(request))

    # arun(Completions(api_key=api_key).create_for_images(request))
    arun(Completions().create_for_files(request))

    # arun(Completions(api_key=api_key).create_for_files(request))

    # request = ImageRequest(
    #     prompt="https://oss.ffire.cc/files/nsfw.jpg 移除右下角 白色的水印",
    #     # prompt="画条可爱的狗",
    #
    # )
    #
    # arun(Completions(api_key=api_key).generate(request))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : fastapi
# @Time         : 2024/1/8 16:05
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from functools import wraps, partial
from fastapi import HTTPException


def catch_exceptions(func=None, *, exception_type=Exception, status_code=404):
    if func is None:
        return partial(catch_exceptions, exception_type=exception_type, status_code=status_code)

    @wraps(func)
    async def async_wrapper(*args, **kwargs):
        try:
            return await func(*args, **kwargs)
        except exception_type as e:
            raise HTTPException(status_code=status_code, detail=f"Error: {e}")

    def sync_wrapper(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except exception_type as e:
            raise HTTPException(status_code=status_code, detail=f"Error: {e}")

    return async_wrapper if asyncio.iscoroutinefunction(func) else sync_wrapper


def catch_exceptions_(func):
    @wraps(func)
    async def wrapper(*args, **kwargs):
        try:
            return await func(*args, **kwargs)
        except CustomException as e:
            return JSONResponse(
                status_code=418,
                content={"message": f"An error occurred: {str(e)}"},
            )
        except Exception as e:
            return JSONResponse(
                status_code=500,
                content={"message": "An unexpected error occurred."}
            )

    return wrapper


# 然后在你的路由中使用装饰器：
# @app.get("/items/{item_id}")
# @catch_exceptions
# async def read_item(item_id: int):
#     # 你的业务逻辑
#     pass


if __name__ == '__main__':
    from meutils.serving.fastapi import App
    from fastapi import Depends

    app = App()


    async def catch_exceptions(exception_type=Exception, status_code=404):
        try:
            yield
        except exception_type as e:
            raise HTTPException(status_code=status_code, detail=f"Error: {e}")


    from fastapi import FastAPI, HTTPException, Depends, Request
    from starlette.responses import JSONResponse



    async def catch_exceptions(request: Request, call_next):
        try:
            response = await call_next(request)
            return response
        except IOError as e:
            return JSONResponse(status_code=500, content={"detail": f"IOError: {e}"})


    @app.middleware("http")
    async def catch_exceptions_middleware(request: Request, call_next):
        return await catch_exceptions(request, call_next)


    @app.get("/test")
    def test_endpoint(file_id: str):
        # Your endpoint logic here
        raise Exception("test")
        # return {"file_id": file_id}



    # @app.get("/test_plus")
    # def test_endpoint(file_id: str, _=Depends(catch_exceptions(exception_type=IOError, status_code=500))):
    #     # Your endpoint logic here
    #     return {"file_id": file_id}


    # @app.get("/test")
    # @catch_exceptions(exception_type=IOError, status_code=500)
    # def f(file_id: str):
    #     logger.debug(file_id)
    #     # raise Exception("test")
    #
    #
    # @app.get("/{file_id}")
    # @catch_exceptions(status_code=1)
    # def f(file_id: str):
    #     logger.debug(file_id)
    #     raise Exception("test")


    app.run(port=9000)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : demo
# @Time         : 2021/2/23 9:01 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : https://www.cnblogs.com/dachenzi/p/8242713.html

from jinja2 import Template, Environment, PackageLoader, FileSystemLoader

# env = Environment(loader=FileSystemLoader('./'))
env = Environment(loader=PackageLoader('meutils'))

template = env.get_template('dsl/dsl_dnn.yml')



print(template.render())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images
# @Time         : 2024/11/13 16:08
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://replicate.com/docs/reference/http#predictions.create

from meutils.pipe import *
from meutils.schemas.image_types import ImageRequest
from meutils.schemas.replicate_types import ReplicateRequest

from meutils.llm.openai_utils import to_openai_images_params, to_openai_params
from meutils.io.files_utils import to_bytes


from openai import AsyncClient, Client


# /v1/predictions

# /images/generations

class ReplicateRequest(BaseModel):
    ref: str
    input: Optional[Dict[str, Any]] = None  # {"prompt": "A majestic lion", "num_outputs": 2}


async def generate(request: ReplicateRequest):
    """
    import replicate
    output = replicate.run(
        "black-forest-labs/flux-schnell",
        input={"prompt": "an iguana on the beach, pointillism"}
    )

    # Save the generated image
    with open('output.png', 'wb') as f:
        f.write(output[0].read())

    print(f"Image saved as output.png")
    """

    prompt = request.input.get('prompt')
    n = request.input.get('num_outputs')

    request = ImageRequest(
        model=request.ref,
        prompt=prompt,
        n=n,
        response_format='url'
    )

    params = to_openai_params(request)

    response = await AsyncClient().images.generate(**params)

    data = await to_bytes(response.data[0].url)

    return data



import replicate
output = replicate.run(
    "black-forest-labs/flux-schnell",
    input={"prompt": "an iguana on the beach, pointillism"}
)

# Save the generated image
with open('output.png', 'wb') as f:
    f.write(output[0].read())

print(f"Image saved as output.png")


replicate.predictions.create()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : spider
# @Time         : 2024/1/18 10:46
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: pdf/截图

from meutils.pipe import *
from meutils.playwright_utils import get_new_page

from fastapi import APIRouter, File, UploadFile, Query, Form, Response, Request

router = APIRouter()


@router.get("/playwright")  # todo: 多个url
@alru_cache(maxsize=10240, ttl=3 * 24 * 3600)
async def get_content(
        url: str,
        # page=Depends(get_new_page) # Depends get_new_page 里面的参数也会暴露出来
):
    url = url.strip()

    page = await get_new_page()
    await page.goto(url)

    if url.startswith("https://mp.weixin.qq.com"):
        content = await page.inner_text('//*[@id="page-content"]')  # 使用page.query_selector_all获取a节点列表
    else:
        # todo: xpath
        # wait
        await page.wait_for_load_state(state='load')
        await page.wait_for_load_state(state='networkidle')
        await page.wait_for_load_state(state='domcontentloaded')
        await page.wait_for_selector('body')

        content = await page.inner_text('body')

    return {"content": content}


if __name__ == '__main__':
    from meutils.serving.fastapi import App

    app = App()
    app.include_router(router)
    app.run(port=39666)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ocr_types
# @Time         : 2024/9/27 10:29
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *


class OCRRequest(BaseModel):
    """
    plain texts OCR & format texts OCR: 这两种模式适用于图像 OCR。
    plain multi-crop OCR & format multi-crop OCR: 对于内容更复杂的图片，您可以使用这些模式获得更高质量的结果。
    plain fine-grained OCR & format fine-grained OCR: 在这些模式下，您可以在输入图片上指定细粒度区域，以实现更灵活的 OCR。细粒度区域可以是方框的坐标、红色、蓝色或绿色。
    """
    image: str

    mode: Literal[
        'simple',
        'plain texts OCR', 'plain multi-crop OCR', 'plain fine-grained OCR',
        'format texts OCR', 'format multi-crop OCR', 'format fine-grained OCR'] = "plain texts OCR"

    fine_grained_mode: Literal['box', 'color'] = "color"
    """plain fine-grained OCR
    "box", "", "[409,763,756,891]"
    "color", "red", ""
    """
    ocr_color: Literal['red', 'green', 'blue'] = "red"
    """plain fine-grained OCR"""
    ocr_box: str = ""
    """plain fine-grained OCR
    The input value that is provided in the "input box: [x1,y1,x2,y2]" Textbox component.
    """



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : message_types
# @Time         : 2024/11/21 19:11
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :


from typing import Union, Iterable, Optional, List
from pydantic import BaseModel, Field
from typing_extensions import Literal


class ChatCompletionContentPartTextParam(BaseModel):
    type: Literal["text"] = "text"
    text: str


class ChatCompletionContentPartRefusalParam(BaseModel):
    type: Literal["refusal"] = "refusal"
    refusal: str


class ChatCompletionMessageToolCallParam(BaseModel):
    id: str
    type: str
    function: dict


class FunctionCall(BaseModel):
    arguments: str = Field(...,
                           description="The arguments to call the function with, as generated by the model in JSON format")
    name: str = Field(..., description="The name of the function to call")


class ChatCompletionToolMessageParam(BaseModel):
    content: Union[str, List[ChatCompletionContentPartTextParam]] = Field(...,
                                                                          description="The contents of the tool message")
    role: Literal["tool"] = Field(..., description="The role of the messages author")
    tool_call_id: str = Field(..., description="Tool call that this message is responding to")


class ChatCompletionUserMessageParam(BaseModel):
    content: Union[str, List[ChatCompletionContentPartTextParam]] = Field(...,
                                                                          description="The contents of the user message")
    role: Literal["user"] = Field(..., description="The role of the messages author")
    name: Optional[str] = Field(None, description="An optional name for the participant")


class ChatCompletionSystemMessageParam(BaseModel):
    content: Union[str, List[ChatCompletionContentPartTextParam]] = Field(...,
                                                                          description="The contents of the system message")
    role: Literal["system"] = Field(..., description="The role of the messages author")
    name: Optional[str] = Field(None, description="An optional name for the participant")


class ChatCompletionFunctionMessageParam(BaseModel):
    content: Optional[str] = Field(..., description="The contents of the function message")
    name: str = Field(..., description="The name of the function to call")
    role: Literal["function"] = Field(..., description="The role of the messages author")


class ChatCompletionAssistantMessageParam(BaseModel):
    role: Literal["assistant"] = Field(..., description="The role of the messages author")
    content: Optional[
        Union[str, List[Union[ChatCompletionContentPartTextParam, ChatCompletionContentPartRefusalParam]]]] = Field(
        None, description="The contents of the assistant message"
    )
    function_call: Optional[FunctionCall] = Field(None,
                                                  description="The name and arguments of a function that should be called")
    name: Optional[str] = Field(None, description="An optional name for the participant")
    refusal: Optional[str] = Field(None, description="The refusal message by the assistant")
    tool_calls: Optional[List[ChatCompletionMessageToolCallParam]] = Field(None,
                                                                           description="The tool calls generated by the model")

class Message(BaseModel):
    role: Literal["system", "user", "assistant"]
    content: Union[str, List[Union[ChatCompletionUserMessageParam, FileUrlContent]], FileUrlContent]

class ChatMessages(BaseModel):
    messages: List[Message]

class ChatCompletionMessageParam(
    ChatCompletionSystemMessageParam,
    ChatCompletionUserMessageParam,
    ChatCompletionAssistantMessageParam,
    ChatCompletionToolMessageParam,
    ChatCompletionFunctionMessageParam
):
    pass


if __name__ == '__main__':
    # 创建一个用户消息
    user_msg = ChatCompletionUserMessageParam(
        role="user",
        content="Hello!",
        name="John"
    )

    # 创建一个系统消息
    system_msg = ChatCompletionSystemMessageParam(
        role="system",
        content="You are a helpful assistant."
    )

    # 创建一个助手消息
    assistant_msg = ChatCompletionAssistantMessageParam(
        role="assistant",
        content="How can I help you today?"
    )

    # 验证消息
    # print(user_msg.model_dump())
    # print(system_msg.model_dump())
    # print(assistant_msg.model_dump())
    messages = [
        {
            'role': 'system',
            'content': '你是一个文件问答助手'
        },
        {
            'role': 'user',
            # 'content': {
            #     "type": "file_url",
            #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            # },
            'content': [
                {
                    "type": "text",
                    "text": "这个文件讲了什么？"
                },
                # 多轮的时候要剔除
                {
                    "type": "file_url",
                    "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
                }
            ]
        },
        {'role': 'assistant', 'content': "好的"},
        {
            'role': 'user',
            # 'content': {
            #     "type": "file_url",
            #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            # },
            'content': [
                {
                    "type": "text",
                    "text": "错了 继续回答"
                },
                # {
                #     "type": "file_url",
                #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
                # }
            ]
        }
    ]

    for message in messages:
        print(ChatCompletionMessageParam(**message))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : subprocess_demo
# @Time         : 2021/1/20 10:38 上午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm
# @Description  : 


import subprocess
# 返回值输出
status, output = subprocess.getstatusoutput('cat /proc/cpuinfo')


subprocess.call('ls')  # 可以直接call()调用

'''
#也可以使用subprocess.Popen
p = subprocess.Popen('ls', shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
for line in p.stdout.readlines():
  print(line)

'''


# scp: https://github.com/jbardin/scp.py


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : nesc.
# @File         : hegui
# @Time         : 2021/11/4 上午10:33
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  :

from urllib import parse
from docxtpl import DocxTemplate, RichText

from meutils.pipe import *
from meutils.str_utils import arabic2chinese
from meutils.date_utils import date_difference
from meutils.request_utils.crawler import Crawler


############################################################
def get_context(url, xpath_map, date, body_xpath="""//*[@class="Custom_UnionStyle"]//text()"""):
    c = Crawler(url)

    context = {}
    for idx, (title_, url_, date_) in enumerate(zip(*[c.xpath(v) for k, v in xpath_map.items()]), 1):
        if date_.strip() == date:
            url_ = parse.urljoin(url, url_)
            lines = Crawler(url_).xpath(body_xpath)
            context[f'{arabic2chinese(idx)[1]}、{title_}'] = ''.join(lines).strip()
    return context


# url = "http://www.csrc.gov.cn/pub/newsite/zjhxwfb/xwdd/"
# xpath_map = {
#     'titles': '//*[@id="myul"]/li[*]/a//text()',
#     'urls': '//*[@id="myul"]/li[*]//@href',
#     'dates': '//*[@id="myul"]/li[*]/span//text()'
# }

url = "http://www.csrc.gov.cn/pub/newsite/zxgx/jigbsdt/"
xpath_map = {
    'titles': '/html/body/div/div/div[5]/div[2]/div/div[2]/ul/li[*]/a//text()',
    'urls': '/html/body/div/div/div[5]/div[2]/div/div[2]/ul/li[*]/a//@href',
    'dates': '/html/body/div/div/div[5]/div[2]/div/div[2]/ul/li[*]/span//text()'
}
监管动态 = get_context(url, xpath_map, '2021-11-04')

url = "http://www.csrc.gov.cn/pub/newsite/zqjjjgjgb/thywwgcfxx/jgb_xzjgl/"
xpath_map = {
    'titles': '//*[@id="myul"]/li[*]/a//text()',
    'urls': '//*[@id="myul"]/li[*]/a//@href',
    'dates': '//*[@id="myul"]/li[*]/span//text()'
}
法律法规跟踪 = get_context(url, xpath_map, '2021-10-15')

############################################################
date = date_difference(fmt='%Y年%m月%d日')
year = date[:4]
context = {
    'year': year,
    'date': date,
    '监管动态': 监管动态,
    '法律法规跟踪': 法律法规跟踪,
}

doc = DocxTemplate('合规日报模板.docx')
doc.render(context)
doc.save('合规日报模板_.docx')






#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : Python.
# @File         : utils
# @Time         : 2022/10/18 下午1:29
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

import streamlit as st
from streamlit.components.v1 import html
from streamlit.elements.image import image_to_url

from meutils.pipe import *


def hide_st_style(footer_content='🔥'):
    _ = f"""
        <style>.css-18e3th9 {{padding-top: 2rem;}}
        #MainMenu {{visibility: hidden;}}
        header {{visibility: hidden;}}
        footer {{visibility: hidden;}}        
        footer:after {{content:"{footer_content}";visibility: visible;display: block;position: absolute;left: 50%;transform: translate(-50%, -100%);}}
        </style>
        """

    st.markdown(_, unsafe_allow_html=True)


def set_footer(prefix="Made with 🔥 by ", author='Betterme', url=None):  # 链接门户、微信
    _ = f"""
    <style>
    .footer {{
        position: fixed;
        left: 0;
        bottom: 0;
        width: 100%;
        background-color: #F5F5F5;
        color: #000000;
        text-align: center;
        border-style: solid;
        border-width: 1px;
        border-color: #DDDDDD;
        padding: 8px;
        }}
    </style>
    <div class="footer">
    <p>{prefix}<a href="{url}" target="_blank">{author}</a></p> 
    </div>
    """
    st.markdown(_, unsafe_allow_html=True)


# 设置文本字体
def set_font():
    _ = f"""
    <style>
    h1,h2,h3,h4,h5,h6 {{
        font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
        font-weight: 400;
    }}
    </style>
    """
    st.markdown(_, unsafe_allow_html=True)


# 设置页面背景色
def set_background_color(color='#f1f1f1'):
    _ = f"""
    <style>
    body {{
        background-color: {color};
    }}
    </style>
    """
    st.markdown(_, unsafe_allow_html=True)


def set_background_image(image=get_module_path('./pics/夕阳.png', __file__)):
    image_url = image_to_url(image, width=-1, clamp=False, channels="RGB", output_format="auto", image_id="")
    _ = f'''
        <style>
            .css-fg4pbf {{
            background-image:url({image_url});
            background-repeat: no-repeat;
            background-size: cover;
            background-position: center center;
            height: 100vh;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            }}
        </style>
    '''
    st.markdown(_, unsafe_allow_html=True)


def set_space(num_lines=1):
    """Adds empty lines to the Streamlit app."""
    for _ in range(num_lines):
        st.write("")


def set_columns_placed(bins=2, default_position=0, gap='small'):  # ("small", "medium", or "large")
    _ = st.columns(spec=bins, gap=gap)
    if len(_) < default_position:
        default_position = -1
    return _[default_position]


def display_pdf(base64_pdf, width='100%', height=1000):
    _ = f"""<embed src="data:application/pdf;base64,{base64_pdf}" width="{width}" height="{height}" type="application/pdf">"""
    st.markdown(_, unsafe_allow_html=True)


def display_pdf4file(file, width='100%', height=500):  # 上传PDF文件
    base64_pdf = base64.b64encode(file.read()).decode('utf-8')
    display_pdf(base64_pdf, width, height)


def display_html(text='会飞的文字'):  # html("""<marquee bgcolor="#00ccff" behavior="alternate">这是一个滚动条</marquee>""")
    _ = f"""
        <marquee direction="down" width="100%" height="100%" behavior="alternate" style="border:solid"  bgcolor="#00FF00">

          <marquee behavior="alternate">

            {text}

          </marquee>

        </marquee>
        """
    st.markdown(_, unsafe_allow_html=True)


def set_button():
    css = """<style>
     .stDownloadButton>button {
         background-color: #0099ff;
        color:#ffffff;
    }

    .stDownloadButton>button:hover {
       background-color: #00ff00;
        color:#ff0000;
       }
    </style>
    """
    html(css)  # st.markdown


def set_config(conf: BaseConfig, conf_path='conf.yaml'):  # todo: 数值改为 slider
    """
    :param conf:
    :param conf_path:
    :return:
    """
    if Path(conf_path).is_file():
        conf = conf.parse_yaml(conf_path)

    form = st.sidebar.form('配置项')  # 位置
    with form:
        for k, v in conf:
            v = type(v)(form.text_input(label=k.title(), value=v, help=k))  # 配置类型
            setattr(conf, k, v)  # 更新配置

        if form.checkbox("是否保存配置"):
            yaml.safe_dump(conf.dict(), open(conf_path, 'w'))  # 固化

        if form.form_submit_button('刷新配置'):
            # form.balloons()
            form.json(conf.dict())

            st.session_state.init = True  # 初始化标识

        return conf


def text_align(text, position='center'):
    """中显示标题"""
    st.markdown(f"<h1 style='text-align: {position};'>{text}</h1>", unsafe_allow_html=True)


def st_js_replace(js_file='4666.*.chunk.js'):
    """汉化
        file_uploader => 4666.*.chunk.js

    """
    st_home = Path(st.__file__).parent
    js_files = st_home.rglob(js_file) | xlist
    for js_file in js_files:
        file_replace(js_file, '"Browse files"', '"选择文件"')
        file_replace(js_file, '"Drag and drop file"', '"点击或拖拽文件至此页面即可上传"')
        file_replace(js_file, '" here"', '" "')
        file_replace(js_file, '"s"', '" "')
        file_replace(js_file, '"Limit "', '"每个文件不超过 "')
        file_replace(js_file, '" per file"', '" "')


class ChatMessage(BaseModel):
    name: str = "assistant"  # "user", "assistant", or str
    avatar: Optional[str] = None
    generator: Any = '我是一条内容'


def st_chat_message(
        message: ChatMessage,
        fhook: Optional[Callable] = None,
        bhook: Optional[Callable] = None,
        is_history: bool = False,
        unsafe_allow_html: bool = False,
        **kwargs
):
    """
    from streamlit_extras.streaming_write import write

    chat_message(ChatMessage())
    chat_message(ChatMessage(name='assistant'))

    def chat_messages(messages: List[ChatMessage]):
        for msg in messages:
            chat_message(msg)

    chat_messages([ChatMessage()] * 10)
    """
    from streamlit_extras.streaming_write import write

    if fhook: fhook()

    with st.chat_message(name=message.name, avatar=message.avatar):
        written_content = write(message.generator, unsafe_allow_html=unsafe_allow_html, **kwargs)
        message.generator = written_content | xfilter(lambda x: x is None) | xjoin('')

    if bhook: bhook()

    st.session_state.messages = st.session_state.get('messages', [])
    if is_history:
        st.session_state.messages.append(message)


if __name__ == '__main__':
    from meutils.serving import streamlit as stt

    stt.st_js_replace()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : todo
# @Time         : 2025/5/12 13:32
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

"""
400 {"code":20015,"message":"length of prompt_tokens (213479) must be less than max_seq_len (65536).","data":null}
"""


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : utils
# @Time         : 2024/11/29 16:22
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 通用异步设计，兼容oneapi监控

from celery.result import AsyncResult

from meutils.pipe import *
from meutils.schemas.task_types import TaskResponse

from meutils.db.orm import update_or_insert
from meutils.schemas.db.oneapi_types import OneapiTask

from meutils.db.redis_db import redis_aclient

from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks


async def create_task(async_task, request: Union[BaseModel, dict]):
    if not isinstance(request, dict):
        request = request.model_dump()

    result = async_task.apply_async(kwargs={"request": request})
    task_id = result.id

    return TaskResponse(task_id=task_id, request_id=task_id)


# {
#   "code": 0,
#   "message": "SUCCEED",
#   "request_id": "CjMkWmdJhuIAAAAAAAS0mA",
#   "data": {
#     "task_id": "CjMkWmdJhuIAAAAAAAS0mA",
#     "task_status": "submitted",
#     "created_at": 1732881630997,
#     "updated_at": 1732881630997
#   }
# }


async def get_task(
        task_id: str,
        remote_get_task: Optional[Callable] = None,
        filter_kwargs: Optional[dict] = None,
        background_tasks: Optional[BackgroundTasks] = None,
):
    """

    :param task_id:
    :param remote_get_task:
    :param filter_kwargs: #######参数可以舍弃
         filter_kwargs = {
            "task_id": task_id, #########理论上只需这个
            "user_id": user_id,
            "platform": "replicate",
            "action": "replicate",  # 模型
        }
    :return:
    """
    filter_kwargs = filter_kwargs or {}
    filter_kwargs["task_id"] = task_id

    result = AsyncResult(id=task_id)
    logger.debug(bjson(result._get_task_meta()))
    # logger.debug(bjson(result.get(timeout=30)))
    logger.debug(result)
    logger.debug(result.ready())
    logger.debug(result.state)

    # if result.status=="PENDING": # worker可能还未启动，会阻塞
    # if await redis_aclient.select(1) and not await redis_aclient.exists(f"celery-task-meta-{task_id}"):
    #     raise HTTPException(status_code=404, detail="TaskID not found")

    if result.ready():
        if result.successful():
            data = result.get(timeout=30).copy()  # 创建任务时：remote task的返回结果 ####### copy避免丢失字段
            logger.debug(bjson(data))
            token = data.pop("system_fingerprint", None)  # 远程任务 token/apikey

            remote_task_id = (
                    data.get("task_id")  # 提前写
                    or data.get("data", {}).get("task_id")
                    or data.get("data", {}).get("id")
                    or data.get("id")
                    or data.get("request_id")
            )

            response = TaskResponse(
                task_id=task_id,

                message="Task completed successfully",
                status=result.status,
                data=data
            )

            if remote_get_task:
                if inspect.iscoroutinefunction(remote_get_task):
                    remote_task_response = await remote_get_task(remote_task_id, token)
                else:
                    remote_task_response = remote_get_task(remote_task_id, token)

                if not isinstance(remote_task_response, dict):
                    remote_task_response = remote_task_response.model_dump()

                # logger.debug(response.model_dump_json(indent=4))
                # logger.debug(bjson(remote_task_response))

                _response = {**response.model_dump(), **remote_task_response}
                response = response.construct(**_response)

                # logger.debug(response.model_dump_json(indent=4))

        else:
            response = TaskResponse(
                task_id=task_id,

                code=1,
                message=str(result.result),
                status=result.status,
            )
    else:
        response = TaskResponse(
            task_id=task_id,

            message="Task is still running",
            status=result.status,
        )

    # 更新到数据库：异步任务
    update_fn = partial(update_oneapi_from_response, task_response=response)
    if background_tasks:
        background_tasks.add_task(update_or_insert, OneapiTask, filter_kwargs, update_fn)
    else:
        await update_or_insert(OneapiTask, filter_kwargs, update_fn)

    return response


# todo: 可以设计更通用的
async def update_oneapi_from_response(task: OneapiTask, task_response: TaskResponse):
    """

    filter_kwargs = {
            "task_id": task_id,
            "user_id": user_id,
            "platform": "replicate",
            "action": "replicate",  # 模型
        }

    需要获取这几个信息 user_id

    """
    # if task.status in {"SUCCESS", "FAILURE"}: return False  # 跳出轮询，不再更新

    task.data = task_response.model_dump(exclude={"system_fingerprint"})
    task.status = task_response.status
    task.progress = time.time() // 10 % 100

    if task.status == "SUCCESS":  ###### todo: 状态对齐
        task.progress = "100%"
    elif task.status == "FAILURE":
        task.fail_reason = "查看详情"

    task.updated_at = int(time.time())
    task.finish_time = int(time.time())  # 不是实际时间


if __name__ == '__main__':
    from meutils.async_task import worker, shared_task  #######重要 需要识别到worker

    from meutils.apis.kling import kolors_virtual_try_on
    from meutils.async_task.tasks import hailuo

    task_id = "7d4fbaf3-f641-482b-b02c-ccd30e61195a"
    # filter_kwargs = {
    #     "task_id": task_id,  #########理论上只需这个
    #     "user_id": 1,
    #     "platform": "kling",
    #     "action": "kling",  # 模型
    # }

    # arun(get_task(task_id, hailuo.get_task))
    #
    # task_id = "e3f76be8-f7eb-4562-a7af-029928d074d5"
    # arun(get_task(task_id, kolors_virtual_try_on.get_task))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AppZoo.
# @File         : zk_utils
# @Time         : 2020/11/11 5:49 下午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm
# @Description  : 

import time
import yaml
import socket
from pathlib import Path
from loguru import logger
from kazoo.client import KazooClient

try:
    zk = KazooClient(hosts='', timeout=1)
    zk.start()
    zk_get_children = zk.get_children  # 获取所有节点

except Exception as e:
    logger.exception(e)
    pass


class ZKConfig(object):
    """便于实时监控zk配置"""
    info = None


def zk_watcher(path, zk_hosts=''):
    """实时监控"""

    zk = KazooClient(hosts=zk_hosts)
    zk.start()

    @zk.DataWatch(path)
    def watcher(data, stat):
        logger.info(f'zk stat: {stat}')
        ZKConfig.info = yaml.safe_load(data)

    return watcher


def zk_logger(log, path='/push/log'):
    if not zk.exists(path):
        zk.create(path, log.encode(), makepath=True)
    else:
        zk.set(path, log.encode())


# @zk.DataWatch('/push/nh_model')
# def watcher(data, stat):  # (data, stat, event)
#     ZKConfig.info = yaml.safe_load(data)

def get_zk_config(zk_path="/push/cfg", hosts='', mode='yaml'):
    zk = KazooClient(hosts)
    zk.start()

    data, stat = zk.get(zk_path)

    if mode == 'yaml':
        return yaml.safe_load(data)
    else:
        return data.decode()


def register_ip(path='/push/ann/ips', sleep_time=10):  # 最后需要 /
    """session 中断后自动删除该节点, 实例重启后自动更新节点

    :param path:
    :return:
    """
    import datetime
    s = datetime.datetime.today()

    ip = socket.gethostbyname(socket.gethostname())
    node = str(Path(path) / ip)

    time.sleep(15)

    if not zk.exists(node):
        zk.create(node, str(s).encode(), makepath=True, ephemeral=True)
    else:
        logger.warning(f"{node} alreadly exists")

    if sleep_time == -1:  # 一直监控
        while 1:
            time.sleep(10000)
    else:
        time.sleep(sleep_time)


# 常用固定
class Config(object):
    pass


zk_cfg = Config()
zk_cfg.__dict__ = yaml.safe_load(zk.get('/push/cfg')[0])  # todo: 具体定义下结构更清晰

if __name__ == '__main__':
    # print(get_zk_config("/push/cfg"))
    # zk_logger('log__', '/push/xxx')
    # print(zk_cfg)
    # print(get_zk_config("/push/email_token"))
    register_ip()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : utils
# @Time         : 2024/12/25 18:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import os

from meutils.pipe import *

from meutils.caches.redis_cache import cache, cache_inmemory
from meutils.db.orm import select_first, update_or_insert
from meutils.schemas.db.oneapi_types import OneapiTask, OneapiUser, OneapiToken


@cache(ttl=15 * 24 * 3600)
async def token2user(api_key: str):
    filter_kwargs = {
        "key": api_key.removeprefix("sk-"),
    }
    # logger.debug(filter_kwargs)
    return await select_first(OneapiToken, filter_kwargs)


@alru_cache(ttl=60)
async def get_user_quota(api_key: Optional[str] = None, user_id: Optional[int] = None):
    assert any([api_key, user_id]), "api_key or user_id must be provided."

    if not user_id:
        token_object = await token2user(api_key)
        user_id = token_object.user_id

    filter_kwargs = {
        "id": user_id
    }
    user_object = await select_first(OneapiUser, filter_kwargs)
    # logger.debug(user_object)
    return user_object.quota / 500000


if __name__ == '__main__':
    # from faker import Faker

    # with timer():
    #     arun(get_user_quota(os.getenv("OPENAI_API_KEY")))
    # arun(get_user_quota(user_id=1))

    # async def task():
    #     filter_kwargs = dict(
    #         username=f"{shortuuid.random(length=6)}@chatfire.com",
    #     )
    #     return await update_or_insert(OneapiUser, filter_kwargs)
    #
    #
    # async def main():
    #     await asyncio.gather(*[task() for _ in range(5000)])
    #
    #
    # arun(main())


    arun(get_user_quota("sk-2KedjhqS6uubaONCS1Dxyq28Tc1P4AtQk3WFfBpzy4enyalH"))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : _🏆_主页.py
# @Time         : 2023/5/21 17:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.serving.streamlit import *

title = Path(__file__).stem.split('_')[-1]
st.set_page_config(title, page_icon='🔥', layout='wide', initial_sidebar_state='collapsed')
st.title(title)
hide_st_style('🔥DevelopedBy@数据科学研发中心-AI团队')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __demo
# @Time         : 2023/7/4 09:02
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
import asyncio
from aiohttp import request
from aiomultiprocess import Pool  # todo


async def func(url):
    await asyncio.sleep(1)
    return url


async def mainmain():
    urls = ["https://www.baidu.com"] * 10  # todo: openai
    async with Pool() as pool:
        results = await pool.map(func, urls)

        logger.debug(results)

        return results


if __name__ == '__main__':
    # Python 3.7
    print(asyncio.run(mainmain()))  # 终端 python 可以通

    # Python 3.6
    # loop = asyncio.get_event_loop()
    # loop.run_until_complete(main())

    # coroutine = mainmain()
    # task = asyncio.ensure_future(coroutine)
    # loop = asyncio.get_event_loop()
    # loop.run_until_complete(task)
